# encoding: utf-8
#
#--
# Copyright (c) 2016 Guy Allard
#--
if Kernel.respond_to?(:require_relative)
  require_relative("./helper")
else
  $:.unshift(File.dirname(__FILE__))
  require 'helper'
end

#
# == Purpose
#
# Tests for the #{UTF8::Validator} implementation.
#
# Some test data pulled directly from:
#
# http://www.cl.cam.ac.uk/~mgk25/ucs/examples/UTF-8-test.txt
#
class TestSurrogateHalfFirstPoint < Test::Unit::TestCase
  #
  def setup
    @validator = UTF8::Validator.new
    @vercheck = ((RUBY_VERSION =~ /1\.9/) or (RUBY_VERSION =~ /2\./)) ? true : false
  end

  #
  def teardown
    @validator = nil
  end

  # These tests should all fail
  def test_0015_utf16_surrogate_pair_first_half

    test_data = [
      "\xd800",      # CPData Name: surrpair n:1
      "\xd801",      # CPData Name: surrpair n:2
      "\xd802",      # CPData Name: surrpair n:3
      "\xd803",      # CPData Name: surrpair n:4
      "\xd804",      # CPData Name: surrpair n:5
      "\xd805",      # CPData Name: surrpair n:6
      "\xd806",      # CPData Name: surrpair n:7
      "\xd807",      # CPData Name: surrpair n:8
      "\xd808",      # CPData Name: surrpair n:9
      "\xd809",      # CPData Name: surrpair n:10
      "\xd80a",      # CPData Name: surrpair n:11
      "\xd80b",      # CPData Name: surrpair n:12
      "\xd80c",      # CPData Name: surrpair n:13
      "\xd80d",      # CPData Name: surrpair n:14
      "\xd80e",      # CPData Name: surrpair n:15
      "\xd80f",      # CPData Name: surrpair n:16
      "\xd810",      # CPData Name: surrpair n:17
      "\xd811",      # CPData Name: surrpair n:18
      "\xd812",      # CPData Name: surrpair n:19
      "\xd813",      # CPData Name: surrpair n:20
      "\xd814",      # CPData Name: surrpair n:21
      "\xd815",      # CPData Name: surrpair n:22
      "\xd816",      # CPData Name: surrpair n:23
      "\xd817",      # CPData Name: surrpair n:24
      "\xd818",      # CPData Name: surrpair n:25
      "\xd819",      # CPData Name: surrpair n:26
      "\xd81a",      # CPData Name: surrpair n:27
      "\xd81b",      # CPData Name: surrpair n:28
      "\xd81c",      # CPData Name: surrpair n:29
      "\xd81d",      # CPData Name: surrpair n:30
      "\xd81e",      # CPData Name: surrpair n:31
      "\xd81f",      # CPData Name: surrpair n:32
      "\xd820",      # CPData Name: surrpair n:33
      "\xd821",      # CPData Name: surrpair n:34
      "\xd822",      # CPData Name: surrpair n:35
      "\xd823",      # CPData Name: surrpair n:36
      "\xd824",      # CPData Name: surrpair n:37
      "\xd825",      # CPData Name: surrpair n:38
      "\xd826",      # CPData Name: surrpair n:39
      "\xd827",      # CPData Name: surrpair n:40
      "\xd828",      # CPData Name: surrpair n:41
      "\xd829",      # CPData Name: surrpair n:42
      "\xd82a",      # CPData Name: surrpair n:43
      "\xd82b",      # CPData Name: surrpair n:44
      "\xd82c",      # CPData Name: surrpair n:45
      "\xd82d",      # CPData Name: surrpair n:46
      "\xd82e",      # CPData Name: surrpair n:47
      "\xd82f",      # CPData Name: surrpair n:48
      "\xd830",      # CPData Name: surrpair n:49
      "\xd831",      # CPData Name: surrpair n:50
      "\xd832",      # CPData Name: surrpair n:51
      "\xd833",      # CPData Name: surrpair n:52
      "\xd834",      # CPData Name: surrpair n:53
      "\xd835",      # CPData Name: surrpair n:54
      "\xd836",      # CPData Name: surrpair n:55
      "\xd837",      # CPData Name: surrpair n:56
      "\xd838",      # CPData Name: surrpair n:57
      "\xd839",      # CPData Name: surrpair n:58
      "\xd83a",      # CPData Name: surrpair n:59
      "\xd83b",      # CPData Name: surrpair n:60
      "\xd83c",      # CPData Name: surrpair n:61
      "\xd83d",      # CPData Name: surrpair n:62
      "\xd83e",      # CPData Name: surrpair n:63
      "\xd83f",      # CPData Name: surrpair n:64
      "\xd840",      # CPData Name: surrpair n:65
      "\xd841",      # CPData Name: surrpair n:66
      "\xd842",      # CPData Name: surrpair n:67
      "\xd843",      # CPData Name: surrpair n:68
      "\xd844",      # CPData Name: surrpair n:69
      "\xd845",      # CPData Name: surrpair n:70
      "\xd846",      # CPData Name: surrpair n:71
      "\xd847",      # CPData Name: surrpair n:72
      "\xd848",      # CPData Name: surrpair n:73
      "\xd849",      # CPData Name: surrpair n:74
      "\xd84a",      # CPData Name: surrpair n:75
      "\xd84b",      # CPData Name: surrpair n:76
      "\xd84c",      # CPData Name: surrpair n:77
      "\xd84d",      # CPData Name: surrpair n:78
      "\xd84e",      # CPData Name: surrpair n:79
      "\xd84f",      # CPData Name: surrpair n:80
      "\xd850",      # CPData Name: surrpair n:81
      "\xd851",      # CPData Name: surrpair n:82
      "\xd852",      # CPData Name: surrpair n:83
      "\xd853",      # CPData Name: surrpair n:84
      "\xd854",      # CPData Name: surrpair n:85
      "\xd855",      # CPData Name: surrpair n:86
      "\xd856",      # CPData Name: surrpair n:87
      "\xd857",      # CPData Name: surrpair n:88
      "\xd858",      # CPData Name: surrpair n:89
      "\xd859",      # CPData Name: surrpair n:90
      "\xd85a",      # CPData Name: surrpair n:91
      "\xd85b",      # CPData Name: surrpair n:92
      "\xd85c",      # CPData Name: surrpair n:93
      "\xd85d",      # CPData Name: surrpair n:94
      "\xd85e",      # CPData Name: surrpair n:95
      "\xd85f",      # CPData Name: surrpair n:96
      "\xd860",      # CPData Name: surrpair n:97
      "\xd861",      # CPData Name: surrpair n:98
      "\xd862",      # CPData Name: surrpair n:99
      "\xd863",      # CPData Name: surrpair n:100
      "\xd864",      # CPData Name: surrpair n:101
      "\xd865",      # CPData Name: surrpair n:102
      "\xd866",      # CPData Name: surrpair n:103
      "\xd867",      # CPData Name: surrpair n:104
      "\xd868",      # CPData Name: surrpair n:105
      "\xd869",      # CPData Name: surrpair n:106
      "\xd86a",      # CPData Name: surrpair n:107
      "\xd86b",      # CPData Name: surrpair n:108
      "\xd86c",      # CPData Name: surrpair n:109
      "\xd86d",      # CPData Name: surrpair n:110
      "\xd86e",      # CPData Name: surrpair n:111
      "\xd86f",      # CPData Name: surrpair n:112
      "\xd870",      # CPData Name: surrpair n:113
      "\xd871",      # CPData Name: surrpair n:114
      "\xd872",      # CPData Name: surrpair n:115
      "\xd873",      # CPData Name: surrpair n:116
      "\xd874",      # CPData Name: surrpair n:117
      "\xd875",      # CPData Name: surrpair n:118
      "\xd876",      # CPData Name: surrpair n:119
      "\xd877",      # CPData Name: surrpair n:120
      "\xd878",      # CPData Name: surrpair n:121
      "\xd879",      # CPData Name: surrpair n:122
      "\xd87a",      # CPData Name: surrpair n:123
      "\xd87b",      # CPData Name: surrpair n:124
      "\xd87c",      # CPData Name: surrpair n:125
      "\xd87d",      # CPData Name: surrpair n:126
      "\xd87e",      # CPData Name: surrpair n:127
      "\xd87f",      # CPData Name: surrpair n:128
      "\xd880",      # CPData Name: surrpair n:129
      "\xd881",      # CPData Name: surrpair n:130
      "\xd882",      # CPData Name: surrpair n:131
      "\xd883",      # CPData Name: surrpair n:132
      "\xd884",      # CPData Name: surrpair n:133
      "\xd885",      # CPData Name: surrpair n:134
      "\xd886",      # CPData Name: surrpair n:135
      "\xd887",      # CPData Name: surrpair n:136
      "\xd888",      # CPData Name: surrpair n:137
      "\xd889",      # CPData Name: surrpair n:138
      "\xd88a",      # CPData Name: surrpair n:139
      "\xd88b",      # CPData Name: surrpair n:140
      "\xd88c",      # CPData Name: surrpair n:141
      "\xd88d",      # CPData Name: surrpair n:142
      "\xd88e",      # CPData Name: surrpair n:143
      "\xd88f",      # CPData Name: surrpair n:144
      "\xd890",      # CPData Name: surrpair n:145
      "\xd891",      # CPData Name: surrpair n:146
      "\xd892",      # CPData Name: surrpair n:147
      "\xd893",      # CPData Name: surrpair n:148
      "\xd894",      # CPData Name: surrpair n:149
      "\xd895",      # CPData Name: surrpair n:150
      "\xd896",      # CPData Name: surrpair n:151
      "\xd897",      # CPData Name: surrpair n:152
      "\xd898",      # CPData Name: surrpair n:153
      "\xd899",      # CPData Name: surrpair n:154
      "\xd89a",      # CPData Name: surrpair n:155
      "\xd89b",      # CPData Name: surrpair n:156
      "\xd89c",      # CPData Name: surrpair n:157
      "\xd89d",      # CPData Name: surrpair n:158
      "\xd89e",      # CPData Name: surrpair n:159
      "\xd89f",      # CPData Name: surrpair n:160
      "\xd8a0",      # CPData Name: surrpair n:161
      "\xd8a1",      # CPData Name: surrpair n:162
      "\xd8a2",      # CPData Name: surrpair n:163
      "\xd8a3",      # CPData Name: surrpair n:164
      "\xd8a4",      # CPData Name: surrpair n:165
      "\xd8a5",      # CPData Name: surrpair n:166
      "\xd8a6",      # CPData Name: surrpair n:167
      "\xd8a7",      # CPData Name: surrpair n:168
      "\xd8a8",      # CPData Name: surrpair n:169
      "\xd8a9",      # CPData Name: surrpair n:170
      "\xd8aa",      # CPData Name: surrpair n:171
      "\xd8ab",      # CPData Name: surrpair n:172
      "\xd8ac",      # CPData Name: surrpair n:173
      "\xd8ad",      # CPData Name: surrpair n:174
      "\xd8ae",      # CPData Name: surrpair n:175
      "\xd8af",      # CPData Name: surrpair n:176
      "\xd8b0",      # CPData Name: surrpair n:177
      "\xd8b1",      # CPData Name: surrpair n:178
      "\xd8b2",      # CPData Name: surrpair n:179
      "\xd8b3",      # CPData Name: surrpair n:180
      "\xd8b4",      # CPData Name: surrpair n:181
      "\xd8b5",      # CPData Name: surrpair n:182
      "\xd8b6",      # CPData Name: surrpair n:183
      "\xd8b7",      # CPData Name: surrpair n:184
      "\xd8b8",      # CPData Name: surrpair n:185
      "\xd8b9",      # CPData Name: surrpair n:186
      "\xd8ba",      # CPData Name: surrpair n:187
      "\xd8bb",      # CPData Name: surrpair n:188
      "\xd8bc",      # CPData Name: surrpair n:189
      "\xd8bd",      # CPData Name: surrpair n:190
      "\xd8be",      # CPData Name: surrpair n:191
      "\xd8bf",      # CPData Name: surrpair n:192
      "\xd8c0",      # CPData Name: surrpair n:193
      "\xd8c1",      # CPData Name: surrpair n:194
      "\xd8c2",      # CPData Name: surrpair n:195
      "\xd8c3",      # CPData Name: surrpair n:196
      "\xd8c4",      # CPData Name: surrpair n:197
      "\xd8c5",      # CPData Name: surrpair n:198
      "\xd8c6",      # CPData Name: surrpair n:199
      "\xd8c7",      # CPData Name: surrpair n:200
      "\xd8c8",      # CPData Name: surrpair n:201
      "\xd8c9",      # CPData Name: surrpair n:202
      "\xd8ca",      # CPData Name: surrpair n:203
      "\xd8cb",      # CPData Name: surrpair n:204
      "\xd8cc",      # CPData Name: surrpair n:205
      "\xd8cd",      # CPData Name: surrpair n:206
      "\xd8ce",      # CPData Name: surrpair n:207
      "\xd8cf",      # CPData Name: surrpair n:208
      "\xd8d0",      # CPData Name: surrpair n:209
      "\xd8d1",      # CPData Name: surrpair n:210
      "\xd8d2",      # CPData Name: surrpair n:211
      "\xd8d3",      # CPData Name: surrpair n:212
      "\xd8d4",      # CPData Name: surrpair n:213
      "\xd8d5",      # CPData Name: surrpair n:214
      "\xd8d6",      # CPData Name: surrpair n:215
      "\xd8d7",      # CPData Name: surrpair n:216
      "\xd8d8",      # CPData Name: surrpair n:217
      "\xd8d9",      # CPData Name: surrpair n:218
      "\xd8da",      # CPData Name: surrpair n:219
      "\xd8db",      # CPData Name: surrpair n:220
      "\xd8dc",      # CPData Name: surrpair n:221
      "\xd8dd",      # CPData Name: surrpair n:222
      "\xd8de",      # CPData Name: surrpair n:223
      "\xd8df",      # CPData Name: surrpair n:224
      "\xd8e0",      # CPData Name: surrpair n:225
      "\xd8e1",      # CPData Name: surrpair n:226
      "\xd8e2",      # CPData Name: surrpair n:227
      "\xd8e3",      # CPData Name: surrpair n:228
      "\xd8e4",      # CPData Name: surrpair n:229
      "\xd8e5",      # CPData Name: surrpair n:230
      "\xd8e6",      # CPData Name: surrpair n:231
      "\xd8e7",      # CPData Name: surrpair n:232
      "\xd8e8",      # CPData Name: surrpair n:233
      "\xd8e9",      # CPData Name: surrpair n:234
      "\xd8ea",      # CPData Name: surrpair n:235
      "\xd8eb",      # CPData Name: surrpair n:236
      "\xd8ec",      # CPData Name: surrpair n:237
      "\xd8ed",      # CPData Name: surrpair n:238
      "\xd8ee",      # CPData Name: surrpair n:239
      "\xd8ef",      # CPData Name: surrpair n:240
      "\xd8f0",      # CPData Name: surrpair n:241
      "\xd8f1",      # CPData Name: surrpair n:242
      "\xd8f2",      # CPData Name: surrpair n:243
      "\xd8f3",      # CPData Name: surrpair n:244
      "\xd8f4",      # CPData Name: surrpair n:245
      "\xd8f5",      # CPData Name: surrpair n:246
      "\xd8f6",      # CPData Name: surrpair n:247
      "\xd8f7",      # CPData Name: surrpair n:248
      "\xd8f8",      # CPData Name: surrpair n:249
      "\xd8f9",      # CPData Name: surrpair n:250
      "\xd8fa",      # CPData Name: surrpair n:251
      "\xd8fb",      # CPData Name: surrpair n:252
      "\xd8fc",      # CPData Name: surrpair n:253
      "\xd8fd",      # CPData Name: surrpair n:254
      "\xd8fe",      # CPData Name: surrpair n:255
      "\xd8ff",      # CPData Name: surrpair n:256
      "\xd900",      # CPData Name: surrpair n:257
      "\xd901",      # CPData Name: surrpair n:258
      "\xd902",      # CPData Name: surrpair n:259
      "\xd903",      # CPData Name: surrpair n:260
      "\xd904",      # CPData Name: surrpair n:261
      "\xd905",      # CPData Name: surrpair n:262
      "\xd906",      # CPData Name: surrpair n:263
      "\xd907",      # CPData Name: surrpair n:264
      "\xd908",      # CPData Name: surrpair n:265
      "\xd909",      # CPData Name: surrpair n:266
      "\xd90a",      # CPData Name: surrpair n:267
      "\xd90b",      # CPData Name: surrpair n:268
      "\xd90c",      # CPData Name: surrpair n:269
      "\xd90d",      # CPData Name: surrpair n:270
      "\xd90e",      # CPData Name: surrpair n:271
      "\xd90f",      # CPData Name: surrpair n:272
      "\xd910",      # CPData Name: surrpair n:273
      "\xd911",      # CPData Name: surrpair n:274
      "\xd912",      # CPData Name: surrpair n:275
      "\xd913",      # CPData Name: surrpair n:276
      "\xd914",      # CPData Name: surrpair n:277
      "\xd915",      # CPData Name: surrpair n:278
      "\xd916",      # CPData Name: surrpair n:279
      "\xd917",      # CPData Name: surrpair n:280
      "\xd918",      # CPData Name: surrpair n:281
      "\xd919",      # CPData Name: surrpair n:282
      "\xd91a",      # CPData Name: surrpair n:283
      "\xd91b",      # CPData Name: surrpair n:284
      "\xd91c",      # CPData Name: surrpair n:285
      "\xd91d",      # CPData Name: surrpair n:286
      "\xd91e",      # CPData Name: surrpair n:287
      "\xd91f",      # CPData Name: surrpair n:288
      "\xd920",      # CPData Name: surrpair n:289
      "\xd921",      # CPData Name: surrpair n:290
      "\xd922",      # CPData Name: surrpair n:291
      "\xd923",      # CPData Name: surrpair n:292
      "\xd924",      # CPData Name: surrpair n:293
      "\xd925",      # CPData Name: surrpair n:294
      "\xd926",      # CPData Name: surrpair n:295
      "\xd927",      # CPData Name: surrpair n:296
      "\xd928",      # CPData Name: surrpair n:297
      "\xd929",      # CPData Name: surrpair n:298
      "\xd92a",      # CPData Name: surrpair n:299
      "\xd92b",      # CPData Name: surrpair n:300
      "\xd92c",      # CPData Name: surrpair n:301
      "\xd92d",      # CPData Name: surrpair n:302
      "\xd92e",      # CPData Name: surrpair n:303
      "\xd92f",      # CPData Name: surrpair n:304
      "\xd930",      # CPData Name: surrpair n:305
      "\xd931",      # CPData Name: surrpair n:306
      "\xd932",      # CPData Name: surrpair n:307
      "\xd933",      # CPData Name: surrpair n:308
      "\xd934",      # CPData Name: surrpair n:309
      "\xd935",      # CPData Name: surrpair n:310
      "\xd936",      # CPData Name: surrpair n:311
      "\xd937",      # CPData Name: surrpair n:312
      "\xd938",      # CPData Name: surrpair n:313
      "\xd939",      # CPData Name: surrpair n:314
      "\xd93a",      # CPData Name: surrpair n:315
      "\xd93b",      # CPData Name: surrpair n:316
      "\xd93c",      # CPData Name: surrpair n:317
      "\xd93d",      # CPData Name: surrpair n:318
      "\xd93e",      # CPData Name: surrpair n:319
      "\xd93f",      # CPData Name: surrpair n:320
      "\xd940",      # CPData Name: surrpair n:321
      "\xd941",      # CPData Name: surrpair n:322
      "\xd942",      # CPData Name: surrpair n:323
      "\xd943",      # CPData Name: surrpair n:324
      "\xd944",      # CPData Name: surrpair n:325
      "\xd945",      # CPData Name: surrpair n:326
      "\xd946",      # CPData Name: surrpair n:327
      "\xd947",      # CPData Name: surrpair n:328
      "\xd948",      # CPData Name: surrpair n:329
      "\xd949",      # CPData Name: surrpair n:330
      "\xd94a",      # CPData Name: surrpair n:331
      "\xd94b",      # CPData Name: surrpair n:332
      "\xd94c",      # CPData Name: surrpair n:333
      "\xd94d",      # CPData Name: surrpair n:334
      "\xd94e",      # CPData Name: surrpair n:335
      "\xd94f",      # CPData Name: surrpair n:336
      "\xd950",      # CPData Name: surrpair n:337
      "\xd951",      # CPData Name: surrpair n:338
      "\xd952",      # CPData Name: surrpair n:339
      "\xd953",      # CPData Name: surrpair n:340
      "\xd954",      # CPData Name: surrpair n:341
      "\xd955",      # CPData Name: surrpair n:342
      "\xd956",      # CPData Name: surrpair n:343
      "\xd957",      # CPData Name: surrpair n:344
      "\xd958",      # CPData Name: surrpair n:345
      "\xd959",      # CPData Name: surrpair n:346
      "\xd95a",      # CPData Name: surrpair n:347
      "\xd95b",      # CPData Name: surrpair n:348
      "\xd95c",      # CPData Name: surrpair n:349
      "\xd95d",      # CPData Name: surrpair n:350
      "\xd95e",      # CPData Name: surrpair n:351
      "\xd95f",      # CPData Name: surrpair n:352
      "\xd960",      # CPData Name: surrpair n:353
      "\xd961",      # CPData Name: surrpair n:354
      "\xd962",      # CPData Name: surrpair n:355
      "\xd963",      # CPData Name: surrpair n:356
      "\xd964",      # CPData Name: surrpair n:357
      "\xd965",      # CPData Name: surrpair n:358
      "\xd966",      # CPData Name: surrpair n:359
      "\xd967",      # CPData Name: surrpair n:360
      "\xd968",      # CPData Name: surrpair n:361
      "\xd969",      # CPData Name: surrpair n:362
      "\xd96a",      # CPData Name: surrpair n:363
      "\xd96b",      # CPData Name: surrpair n:364
      "\xd96c",      # CPData Name: surrpair n:365
      "\xd96d",      # CPData Name: surrpair n:366
      "\xd96e",      # CPData Name: surrpair n:367
      "\xd96f",      # CPData Name: surrpair n:368
      "\xd970",      # CPData Name: surrpair n:369
      "\xd971",      # CPData Name: surrpair n:370
      "\xd972",      # CPData Name: surrpair n:371
      "\xd973",      # CPData Name: surrpair n:372
      "\xd974",      # CPData Name: surrpair n:373
      "\xd975",      # CPData Name: surrpair n:374
      "\xd976",      # CPData Name: surrpair n:375
      "\xd977",      # CPData Name: surrpair n:376
      "\xd978",      # CPData Name: surrpair n:377
      "\xd979",      # CPData Name: surrpair n:378
      "\xd97a",      # CPData Name: surrpair n:379
      "\xd97b",      # CPData Name: surrpair n:380
      "\xd97c",      # CPData Name: surrpair n:381
      "\xd97d",      # CPData Name: surrpair n:382
      "\xd97e",      # CPData Name: surrpair n:383
      "\xd97f",      # CPData Name: surrpair n:384
      "\xd980",      # CPData Name: surrpair n:385
      "\xd981",      # CPData Name: surrpair n:386
      "\xd982",      # CPData Name: surrpair n:387
      "\xd983",      # CPData Name: surrpair n:388
      "\xd984",      # CPData Name: surrpair n:389
      "\xd985",      # CPData Name: surrpair n:390
      "\xd986",      # CPData Name: surrpair n:391
      "\xd987",      # CPData Name: surrpair n:392
      "\xd988",      # CPData Name: surrpair n:393
      "\xd989",      # CPData Name: surrpair n:394
      "\xd98a",      # CPData Name: surrpair n:395
      "\xd98b",      # CPData Name: surrpair n:396
      "\xd98c",      # CPData Name: surrpair n:397
      "\xd98d",      # CPData Name: surrpair n:398
      "\xd98e",      # CPData Name: surrpair n:399
      "\xd98f",      # CPData Name: surrpair n:400
      "\xd990",      # CPData Name: surrpair n:401
      "\xd991",      # CPData Name: surrpair n:402
      "\xd992",      # CPData Name: surrpair n:403
      "\xd993",      # CPData Name: surrpair n:404
      "\xd994",      # CPData Name: surrpair n:405
      "\xd995",      # CPData Name: surrpair n:406
      "\xd996",      # CPData Name: surrpair n:407
      "\xd997",      # CPData Name: surrpair n:408
      "\xd998",      # CPData Name: surrpair n:409
      "\xd999",      # CPData Name: surrpair n:410
      "\xd99a",      # CPData Name: surrpair n:411
      "\xd99b",      # CPData Name: surrpair n:412
      "\xd99c",      # CPData Name: surrpair n:413
      "\xd99d",      # CPData Name: surrpair n:414
      "\xd99e",      # CPData Name: surrpair n:415
      "\xd99f",      # CPData Name: surrpair n:416
      "\xd9a0",      # CPData Name: surrpair n:417
      "\xd9a1",      # CPData Name: surrpair n:418
      "\xd9a2",      # CPData Name: surrpair n:419
      "\xd9a3",      # CPData Name: surrpair n:420
      "\xd9a4",      # CPData Name: surrpair n:421
      "\xd9a5",      # CPData Name: surrpair n:422
      "\xd9a6",      # CPData Name: surrpair n:423
      "\xd9a7",      # CPData Name: surrpair n:424
      "\xd9a8",      # CPData Name: surrpair n:425
      "\xd9a9",      # CPData Name: surrpair n:426
      "\xd9aa",      # CPData Name: surrpair n:427
      "\xd9ab",      # CPData Name: surrpair n:428
      "\xd9ac",      # CPData Name: surrpair n:429
      "\xd9ad",      # CPData Name: surrpair n:430
      "\xd9ae",      # CPData Name: surrpair n:431
      "\xd9af",      # CPData Name: surrpair n:432
      "\xd9b0",      # CPData Name: surrpair n:433
      "\xd9b1",      # CPData Name: surrpair n:434
      "\xd9b2",      # CPData Name: surrpair n:435
      "\xd9b3",      # CPData Name: surrpair n:436
      "\xd9b4",      # CPData Name: surrpair n:437
      "\xd9b5",      # CPData Name: surrpair n:438
      "\xd9b6",      # CPData Name: surrpair n:439
      "\xd9b7",      # CPData Name: surrpair n:440
      "\xd9b8",      # CPData Name: surrpair n:441
      "\xd9b9",      # CPData Name: surrpair n:442
      "\xd9ba",      # CPData Name: surrpair n:443
      "\xd9bb",      # CPData Name: surrpair n:444
      "\xd9bc",      # CPData Name: surrpair n:445
      "\xd9bd",      # CPData Name: surrpair n:446
      "\xd9be",      # CPData Name: surrpair n:447
      "\xd9bf",      # CPData Name: surrpair n:448
      "\xd9c0",      # CPData Name: surrpair n:449
      "\xd9c1",      # CPData Name: surrpair n:450
      "\xd9c2",      # CPData Name: surrpair n:451
      "\xd9c3",      # CPData Name: surrpair n:452
      "\xd9c4",      # CPData Name: surrpair n:453
      "\xd9c5",      # CPData Name: surrpair n:454
      "\xd9c6",      # CPData Name: surrpair n:455
      "\xd9c7",      # CPData Name: surrpair n:456
      "\xd9c8",      # CPData Name: surrpair n:457
      "\xd9c9",      # CPData Name: surrpair n:458
      "\xd9ca",      # CPData Name: surrpair n:459
      "\xd9cb",      # CPData Name: surrpair n:460
      "\xd9cc",      # CPData Name: surrpair n:461
      "\xd9cd",      # CPData Name: surrpair n:462
      "\xd9ce",      # CPData Name: surrpair n:463
      "\xd9cf",      # CPData Name: surrpair n:464
      "\xd9d0",      # CPData Name: surrpair n:465
      "\xd9d1",      # CPData Name: surrpair n:466
      "\xd9d2",      # CPData Name: surrpair n:467
      "\xd9d3",      # CPData Name: surrpair n:468
      "\xd9d4",      # CPData Name: surrpair n:469
      "\xd9d5",      # CPData Name: surrpair n:470
      "\xd9d6",      # CPData Name: surrpair n:471
      "\xd9d7",      # CPData Name: surrpair n:472
      "\xd9d8",      # CPData Name: surrpair n:473
      "\xd9d9",      # CPData Name: surrpair n:474
      "\xd9da",      # CPData Name: surrpair n:475
      "\xd9db",      # CPData Name: surrpair n:476
      "\xd9dc",      # CPData Name: surrpair n:477
      "\xd9dd",      # CPData Name: surrpair n:478
      "\xd9de",      # CPData Name: surrpair n:479
      "\xd9df",      # CPData Name: surrpair n:480
      "\xd9e0",      # CPData Name: surrpair n:481
      "\xd9e1",      # CPData Name: surrpair n:482
      "\xd9e2",      # CPData Name: surrpair n:483
      "\xd9e3",      # CPData Name: surrpair n:484
      "\xd9e4",      # CPData Name: surrpair n:485
      "\xd9e5",      # CPData Name: surrpair n:486
      "\xd9e6",      # CPData Name: surrpair n:487
      "\xd9e7",      # CPData Name: surrpair n:488
      "\xd9e8",      # CPData Name: surrpair n:489
      "\xd9e9",      # CPData Name: surrpair n:490
      "\xd9ea",      # CPData Name: surrpair n:491
      "\xd9eb",      # CPData Name: surrpair n:492
      "\xd9ec",      # CPData Name: surrpair n:493
      "\xd9ed",      # CPData Name: surrpair n:494
      "\xd9ee",      # CPData Name: surrpair n:495
      "\xd9ef",      # CPData Name: surrpair n:496
      "\xd9f0",      # CPData Name: surrpair n:497
      "\xd9f1",      # CPData Name: surrpair n:498
      "\xd9f2",      # CPData Name: surrpair n:499
      "\xd9f3",      # CPData Name: surrpair n:500
      "\xd9f4",      # CPData Name: surrpair n:501
      "\xd9f5",      # CPData Name: surrpair n:502
      "\xd9f6",      # CPData Name: surrpair n:503
      "\xd9f7",      # CPData Name: surrpair n:504
      "\xd9f8",      # CPData Name: surrpair n:505
      "\xd9f9",      # CPData Name: surrpair n:506
      "\xd9fa",      # CPData Name: surrpair n:507
      "\xd9fb",      # CPData Name: surrpair n:508
      "\xd9fc",      # CPData Name: surrpair n:509
      "\xd9fd",      # CPData Name: surrpair n:510
      "\xd9fe",      # CPData Name: surrpair n:511
      "\xd9ff",      # CPData Name: surrpair n:512
      "\xda00",      # CPData Name: surrpair n:513
      "\xda01",      # CPData Name: surrpair n:514
      "\xda02",      # CPData Name: surrpair n:515
      "\xda03",      # CPData Name: surrpair n:516
      "\xda04",      # CPData Name: surrpair n:517
      "\xda05",      # CPData Name: surrpair n:518
      "\xda06",      # CPData Name: surrpair n:519
      "\xda07",      # CPData Name: surrpair n:520
      "\xda08",      # CPData Name: surrpair n:521
      "\xda09",      # CPData Name: surrpair n:522
      "\xda0a",      # CPData Name: surrpair n:523
      "\xda0b",      # CPData Name: surrpair n:524
      "\xda0c",      # CPData Name: surrpair n:525
      "\xda0d",      # CPData Name: surrpair n:526
      "\xda0e",      # CPData Name: surrpair n:527
      "\xda0f",      # CPData Name: surrpair n:528
      "\xda10",      # CPData Name: surrpair n:529
      "\xda11",      # CPData Name: surrpair n:530
      "\xda12",      # CPData Name: surrpair n:531
      "\xda13",      # CPData Name: surrpair n:532
      "\xda14",      # CPData Name: surrpair n:533
      "\xda15",      # CPData Name: surrpair n:534
      "\xda16",      # CPData Name: surrpair n:535
      "\xda17",      # CPData Name: surrpair n:536
      "\xda18",      # CPData Name: surrpair n:537
      "\xda19",      # CPData Name: surrpair n:538
      "\xda1a",      # CPData Name: surrpair n:539
      "\xda1b",      # CPData Name: surrpair n:540
      "\xda1c",      # CPData Name: surrpair n:541
      "\xda1d",      # CPData Name: surrpair n:542
      "\xda1e",      # CPData Name: surrpair n:543
      "\xda1f",      # CPData Name: surrpair n:544
      "\xda20",      # CPData Name: surrpair n:545
      "\xda21",      # CPData Name: surrpair n:546
      "\xda22",      # CPData Name: surrpair n:547
      "\xda23",      # CPData Name: surrpair n:548
      "\xda24",      # CPData Name: surrpair n:549
      "\xda25",      # CPData Name: surrpair n:550
      "\xda26",      # CPData Name: surrpair n:551
      "\xda27",      # CPData Name: surrpair n:552
      "\xda28",      # CPData Name: surrpair n:553
      "\xda29",      # CPData Name: surrpair n:554
      "\xda2a",      # CPData Name: surrpair n:555
      "\xda2b",      # CPData Name: surrpair n:556
      "\xda2c",      # CPData Name: surrpair n:557
      "\xda2d",      # CPData Name: surrpair n:558
      "\xda2e",      # CPData Name: surrpair n:559
      "\xda2f",      # CPData Name: surrpair n:560
      "\xda30",      # CPData Name: surrpair n:561
      "\xda31",      # CPData Name: surrpair n:562
      "\xda32",      # CPData Name: surrpair n:563
      "\xda33",      # CPData Name: surrpair n:564
      "\xda34",      # CPData Name: surrpair n:565
      "\xda35",      # CPData Name: surrpair n:566
      "\xda36",      # CPData Name: surrpair n:567
      "\xda37",      # CPData Name: surrpair n:568
      "\xda38",      # CPData Name: surrpair n:569
      "\xda39",      # CPData Name: surrpair n:570
      "\xda3a",      # CPData Name: surrpair n:571
      "\xda3b",      # CPData Name: surrpair n:572
      "\xda3c",      # CPData Name: surrpair n:573
      "\xda3d",      # CPData Name: surrpair n:574
      "\xda3e",      # CPData Name: surrpair n:575
      "\xda3f",      # CPData Name: surrpair n:576
      "\xda40",      # CPData Name: surrpair n:577
      "\xda41",      # CPData Name: surrpair n:578
      "\xda42",      # CPData Name: surrpair n:579
      "\xda43",      # CPData Name: surrpair n:580
      "\xda44",      # CPData Name: surrpair n:581
      "\xda45",      # CPData Name: surrpair n:582
      "\xda46",      # CPData Name: surrpair n:583
      "\xda47",      # CPData Name: surrpair n:584
      "\xda48",      # CPData Name: surrpair n:585
      "\xda49",      # CPData Name: surrpair n:586
      "\xda4a",      # CPData Name: surrpair n:587
      "\xda4b",      # CPData Name: surrpair n:588
      "\xda4c",      # CPData Name: surrpair n:589
      "\xda4d",      # CPData Name: surrpair n:590
      "\xda4e",      # CPData Name: surrpair n:591
      "\xda4f",      # CPData Name: surrpair n:592
      "\xda50",      # CPData Name: surrpair n:593
      "\xda51",      # CPData Name: surrpair n:594
      "\xda52",      # CPData Name: surrpair n:595
      "\xda53",      # CPData Name: surrpair n:596
      "\xda54",      # CPData Name: surrpair n:597
      "\xda55",      # CPData Name: surrpair n:598
      "\xda56",      # CPData Name: surrpair n:599
      "\xda57",      # CPData Name: surrpair n:600
      "\xda58",      # CPData Name: surrpair n:601
      "\xda59",      # CPData Name: surrpair n:602
      "\xda5a",      # CPData Name: surrpair n:603
      "\xda5b",      # CPData Name: surrpair n:604
      "\xda5c",      # CPData Name: surrpair n:605
      "\xda5d",      # CPData Name: surrpair n:606
      "\xda5e",      # CPData Name: surrpair n:607
      "\xda5f",      # CPData Name: surrpair n:608
      "\xda60",      # CPData Name: surrpair n:609
      "\xda61",      # CPData Name: surrpair n:610
      "\xda62",      # CPData Name: surrpair n:611
      "\xda63",      # CPData Name: surrpair n:612
      "\xda64",      # CPData Name: surrpair n:613
      "\xda65",      # CPData Name: surrpair n:614
      "\xda66",      # CPData Name: surrpair n:615
      "\xda67",      # CPData Name: surrpair n:616
      "\xda68",      # CPData Name: surrpair n:617
      "\xda69",      # CPData Name: surrpair n:618
      "\xda6a",      # CPData Name: surrpair n:619
      "\xda6b",      # CPData Name: surrpair n:620
      "\xda6c",      # CPData Name: surrpair n:621
      "\xda6d",      # CPData Name: surrpair n:622
      "\xda6e",      # CPData Name: surrpair n:623
      "\xda6f",      # CPData Name: surrpair n:624
      "\xda70",      # CPData Name: surrpair n:625
      "\xda71",      # CPData Name: surrpair n:626
      "\xda72",      # CPData Name: surrpair n:627
      "\xda73",      # CPData Name: surrpair n:628
      "\xda74",      # CPData Name: surrpair n:629
      "\xda75",      # CPData Name: surrpair n:630
      "\xda76",      # CPData Name: surrpair n:631
      "\xda77",      # CPData Name: surrpair n:632
      "\xda78",      # CPData Name: surrpair n:633
      "\xda79",      # CPData Name: surrpair n:634
      "\xda7a",      # CPData Name: surrpair n:635
      "\xda7b",      # CPData Name: surrpair n:636
      "\xda7c",      # CPData Name: surrpair n:637
      "\xda7d",      # CPData Name: surrpair n:638
      "\xda7e",      # CPData Name: surrpair n:639
      "\xda7f",      # CPData Name: surrpair n:640
      "\xda80",      # CPData Name: surrpair n:641
      "\xda81",      # CPData Name: surrpair n:642
      "\xda82",      # CPData Name: surrpair n:643
      "\xda83",      # CPData Name: surrpair n:644
      "\xda84",      # CPData Name: surrpair n:645
      "\xda85",      # CPData Name: surrpair n:646
      "\xda86",      # CPData Name: surrpair n:647
      "\xda87",      # CPData Name: surrpair n:648
      "\xda88",      # CPData Name: surrpair n:649
      "\xda89",      # CPData Name: surrpair n:650
      "\xda8a",      # CPData Name: surrpair n:651
      "\xda8b",      # CPData Name: surrpair n:652
      "\xda8c",      # CPData Name: surrpair n:653
      "\xda8d",      # CPData Name: surrpair n:654
      "\xda8e",      # CPData Name: surrpair n:655
      "\xda8f",      # CPData Name: surrpair n:656
      "\xda90",      # CPData Name: surrpair n:657
      "\xda91",      # CPData Name: surrpair n:658
      "\xda92",      # CPData Name: surrpair n:659
      "\xda93",      # CPData Name: surrpair n:660
      "\xda94",      # CPData Name: surrpair n:661
      "\xda95",      # CPData Name: surrpair n:662
      "\xda96",      # CPData Name: surrpair n:663
      "\xda97",      # CPData Name: surrpair n:664
      "\xda98",      # CPData Name: surrpair n:665
      "\xda99",      # CPData Name: surrpair n:666
      "\xda9a",      # CPData Name: surrpair n:667
      "\xda9b",      # CPData Name: surrpair n:668
      "\xda9c",      # CPData Name: surrpair n:669
      "\xda9d",      # CPData Name: surrpair n:670
      "\xda9e",      # CPData Name: surrpair n:671
      "\xda9f",      # CPData Name: surrpair n:672
      "\xdaa0",      # CPData Name: surrpair n:673
      "\xdaa1",      # CPData Name: surrpair n:674
      "\xdaa2",      # CPData Name: surrpair n:675
      "\xdaa3",      # CPData Name: surrpair n:676
      "\xdaa4",      # CPData Name: surrpair n:677
      "\xdaa5",      # CPData Name: surrpair n:678
      "\xdaa6",      # CPData Name: surrpair n:679
      "\xdaa7",      # CPData Name: surrpair n:680
      "\xdaa8",      # CPData Name: surrpair n:681
      "\xdaa9",      # CPData Name: surrpair n:682
      "\xdaaa",      # CPData Name: surrpair n:683
      "\xdaab",      # CPData Name: surrpair n:684
      "\xdaac",      # CPData Name: surrpair n:685
      "\xdaad",      # CPData Name: surrpair n:686
      "\xdaae",      # CPData Name: surrpair n:687
      "\xdaaf",      # CPData Name: surrpair n:688
      "\xdab0",      # CPData Name: surrpair n:689
      "\xdab1",      # CPData Name: surrpair n:690
      "\xdab2",      # CPData Name: surrpair n:691
      "\xdab3",      # CPData Name: surrpair n:692
      "\xdab4",      # CPData Name: surrpair n:693
      "\xdab5",      # CPData Name: surrpair n:694
      "\xdab6",      # CPData Name: surrpair n:695
      "\xdab7",      # CPData Name: surrpair n:696
      "\xdab8",      # CPData Name: surrpair n:697
      "\xdab9",      # CPData Name: surrpair n:698
      "\xdaba",      # CPData Name: surrpair n:699
      "\xdabb",      # CPData Name: surrpair n:700
      "\xdabc",      # CPData Name: surrpair n:701
      "\xdabd",      # CPData Name: surrpair n:702
      "\xdabe",      # CPData Name: surrpair n:703
      "\xdabf",      # CPData Name: surrpair n:704
      "\xdac0",      # CPData Name: surrpair n:705
      "\xdac1",      # CPData Name: surrpair n:706
      "\xdac2",      # CPData Name: surrpair n:707
      "\xdac3",      # CPData Name: surrpair n:708
      "\xdac4",      # CPData Name: surrpair n:709
      "\xdac5",      # CPData Name: surrpair n:710
      "\xdac6",      # CPData Name: surrpair n:711
      "\xdac7",      # CPData Name: surrpair n:712
      "\xdac8",      # CPData Name: surrpair n:713
      "\xdac9",      # CPData Name: surrpair n:714
      "\xdaca",      # CPData Name: surrpair n:715
      "\xdacb",      # CPData Name: surrpair n:716
      "\xdacc",      # CPData Name: surrpair n:717
      "\xdacd",      # CPData Name: surrpair n:718
      "\xdace",      # CPData Name: surrpair n:719
      "\xdacf",      # CPData Name: surrpair n:720
      "\xdad0",      # CPData Name: surrpair n:721
      "\xdad1",      # CPData Name: surrpair n:722
      "\xdad2",      # CPData Name: surrpair n:723
      "\xdad3",      # CPData Name: surrpair n:724
      "\xdad4",      # CPData Name: surrpair n:725
      "\xdad5",      # CPData Name: surrpair n:726
      "\xdad6",      # CPData Name: surrpair n:727
      "\xdad7",      # CPData Name: surrpair n:728
      "\xdad8",      # CPData Name: surrpair n:729
      "\xdad9",      # CPData Name: surrpair n:730
      "\xdada",      # CPData Name: surrpair n:731
      "\xdadb",      # CPData Name: surrpair n:732
      "\xdadc",      # CPData Name: surrpair n:733
      "\xdadd",      # CPData Name: surrpair n:734
      "\xdade",      # CPData Name: surrpair n:735
      "\xdadf",      # CPData Name: surrpair n:736
      "\xdae0",      # CPData Name: surrpair n:737
      "\xdae1",      # CPData Name: surrpair n:738
      "\xdae2",      # CPData Name: surrpair n:739
      "\xdae3",      # CPData Name: surrpair n:740
      "\xdae4",      # CPData Name: surrpair n:741
      "\xdae5",      # CPData Name: surrpair n:742
      "\xdae6",      # CPData Name: surrpair n:743
      "\xdae7",      # CPData Name: surrpair n:744
      "\xdae8",      # CPData Name: surrpair n:745
      "\xdae9",      # CPData Name: surrpair n:746
      "\xdaea",      # CPData Name: surrpair n:747
      "\xdaeb",      # CPData Name: surrpair n:748
      "\xdaec",      # CPData Name: surrpair n:749
      "\xdaed",      # CPData Name: surrpair n:750
      "\xdaee",      # CPData Name: surrpair n:751
      "\xdaef",      # CPData Name: surrpair n:752
      "\xdaf0",      # CPData Name: surrpair n:753
      "\xdaf1",      # CPData Name: surrpair n:754
      "\xdaf2",      # CPData Name: surrpair n:755
      "\xdaf3",      # CPData Name: surrpair n:756
      "\xdaf4",      # CPData Name: surrpair n:757
      "\xdaf5",      # CPData Name: surrpair n:758
      "\xdaf6",      # CPData Name: surrpair n:759
      "\xdaf7",      # CPData Name: surrpair n:760
      "\xdaf8",      # CPData Name: surrpair n:761
      "\xdaf9",      # CPData Name: surrpair n:762
      "\xdafa",      # CPData Name: surrpair n:763
      "\xdafb",      # CPData Name: surrpair n:764
      "\xdafc",      # CPData Name: surrpair n:765
      "\xdafd",      # CPData Name: surrpair n:766
      "\xdafe",      # CPData Name: surrpair n:767
      "\xdaff",      # CPData Name: surrpair n:768
      "\xdb00",      # CPData Name: surrpair n:769
      "\xdb01",      # CPData Name: surrpair n:770
      "\xdb02",      # CPData Name: surrpair n:771
      "\xdb03",      # CPData Name: surrpair n:772
      "\xdb04",      # CPData Name: surrpair n:773
      "\xdb05",      # CPData Name: surrpair n:774
      "\xdb06",      # CPData Name: surrpair n:775
      "\xdb07",      # CPData Name: surrpair n:776
      "\xdb08",      # CPData Name: surrpair n:777
      "\xdb09",      # CPData Name: surrpair n:778
      "\xdb0a",      # CPData Name: surrpair n:779
      "\xdb0b",      # CPData Name: surrpair n:780
      "\xdb0c",      # CPData Name: surrpair n:781
      "\xdb0d",      # CPData Name: surrpair n:782
      "\xdb0e",      # CPData Name: surrpair n:783
      "\xdb0f",      # CPData Name: surrpair n:784
      "\xdb10",      # CPData Name: surrpair n:785
      "\xdb11",      # CPData Name: surrpair n:786
      "\xdb12",      # CPData Name: surrpair n:787
      "\xdb13",      # CPData Name: surrpair n:788
      "\xdb14",      # CPData Name: surrpair n:789
      "\xdb15",      # CPData Name: surrpair n:790
      "\xdb16",      # CPData Name: surrpair n:791
      "\xdb17",      # CPData Name: surrpair n:792
      "\xdb18",      # CPData Name: surrpair n:793
      "\xdb19",      # CPData Name: surrpair n:794
      "\xdb1a",      # CPData Name: surrpair n:795
      "\xdb1b",      # CPData Name: surrpair n:796
      "\xdb1c",      # CPData Name: surrpair n:797
      "\xdb1d",      # CPData Name: surrpair n:798
      "\xdb1e",      # CPData Name: surrpair n:799
      "\xdb1f",      # CPData Name: surrpair n:800
      "\xdb20",      # CPData Name: surrpair n:801
      "\xdb21",      # CPData Name: surrpair n:802
      "\xdb22",      # CPData Name: surrpair n:803
      "\xdb23",      # CPData Name: surrpair n:804
      "\xdb24",      # CPData Name: surrpair n:805
      "\xdb25",      # CPData Name: surrpair n:806
      "\xdb26",      # CPData Name: surrpair n:807
      "\xdb27",      # CPData Name: surrpair n:808
      "\xdb28",      # CPData Name: surrpair n:809
      "\xdb29",      # CPData Name: surrpair n:810
      "\xdb2a",      # CPData Name: surrpair n:811
      "\xdb2b",      # CPData Name: surrpair n:812
      "\xdb2c",      # CPData Name: surrpair n:813
      "\xdb2d",      # CPData Name: surrpair n:814
      "\xdb2e",      # CPData Name: surrpair n:815
      "\xdb2f",      # CPData Name: surrpair n:816
      "\xdb30",      # CPData Name: surrpair n:817
      "\xdb31",      # CPData Name: surrpair n:818
      "\xdb32",      # CPData Name: surrpair n:819
      "\xdb33",      # CPData Name: surrpair n:820
      "\xdb34",      # CPData Name: surrpair n:821
      "\xdb35",      # CPData Name: surrpair n:822
      "\xdb36",      # CPData Name: surrpair n:823
      "\xdb37",      # CPData Name: surrpair n:824
      "\xdb38",      # CPData Name: surrpair n:825
      "\xdb39",      # CPData Name: surrpair n:826
      "\xdb3a",      # CPData Name: surrpair n:827
      "\xdb3b",      # CPData Name: surrpair n:828
      "\xdb3c",      # CPData Name: surrpair n:829
      "\xdb3d",      # CPData Name: surrpair n:830
      "\xdb3e",      # CPData Name: surrpair n:831
      "\xdb3f",      # CPData Name: surrpair n:832
      "\xdb40",      # CPData Name: surrpair n:833
      "\xdb41",      # CPData Name: surrpair n:834
      "\xdb42",      # CPData Name: surrpair n:835
      "\xdb43",      # CPData Name: surrpair n:836
      "\xdb44",      # CPData Name: surrpair n:837
      "\xdb45",      # CPData Name: surrpair n:838
      "\xdb46",      # CPData Name: surrpair n:839
      "\xdb47",      # CPData Name: surrpair n:840
      "\xdb48",      # CPData Name: surrpair n:841
      "\xdb49",      # CPData Name: surrpair n:842
      "\xdb4a",      # CPData Name: surrpair n:843
      "\xdb4b",      # CPData Name: surrpair n:844
      "\xdb4c",      # CPData Name: surrpair n:845
      "\xdb4d",      # CPData Name: surrpair n:846
      "\xdb4e",      # CPData Name: surrpair n:847
      "\xdb4f",      # CPData Name: surrpair n:848
      "\xdb50",      # CPData Name: surrpair n:849
      "\xdb51",      # CPData Name: surrpair n:850
      "\xdb52",      # CPData Name: surrpair n:851
      "\xdb53",      # CPData Name: surrpair n:852
      "\xdb54",      # CPData Name: surrpair n:853
      "\xdb55",      # CPData Name: surrpair n:854
      "\xdb56",      # CPData Name: surrpair n:855
      "\xdb57",      # CPData Name: surrpair n:856
      "\xdb58",      # CPData Name: surrpair n:857
      "\xdb59",      # CPData Name: surrpair n:858
      "\xdb5a",      # CPData Name: surrpair n:859
      "\xdb5b",      # CPData Name: surrpair n:860
      "\xdb5c",      # CPData Name: surrpair n:861
      "\xdb5d",      # CPData Name: surrpair n:862
      "\xdb5e",      # CPData Name: surrpair n:863
      "\xdb5f",      # CPData Name: surrpair n:864
      "\xdb60",      # CPData Name: surrpair n:865
      "\xdb61",      # CPData Name: surrpair n:866
      "\xdb62",      # CPData Name: surrpair n:867
      "\xdb63",      # CPData Name: surrpair n:868
      "\xdb64",      # CPData Name: surrpair n:869
      "\xdb65",      # CPData Name: surrpair n:870
      "\xdb66",      # CPData Name: surrpair n:871
      "\xdb67",      # CPData Name: surrpair n:872
      "\xdb68",      # CPData Name: surrpair n:873
      "\xdb69",      # CPData Name: surrpair n:874
      "\xdb6a",      # CPData Name: surrpair n:875
      "\xdb6b",      # CPData Name: surrpair n:876
      "\xdb6c",      # CPData Name: surrpair n:877
      "\xdb6d",      # CPData Name: surrpair n:878
      "\xdb6e",      # CPData Name: surrpair n:879
      "\xdb6f",      # CPData Name: surrpair n:880
      "\xdb70",      # CPData Name: surrpair n:881
      "\xdb71",      # CPData Name: surrpair n:882
      "\xdb72",      # CPData Name: surrpair n:883
      "\xdb73",      # CPData Name: surrpair n:884
      "\xdb74",      # CPData Name: surrpair n:885
      "\xdb75",      # CPData Name: surrpair n:886
      "\xdb76",      # CPData Name: surrpair n:887
      "\xdb77",      # CPData Name: surrpair n:888
      "\xdb78",      # CPData Name: surrpair n:889
      "\xdb79",      # CPData Name: surrpair n:890
      "\xdb7a",      # CPData Name: surrpair n:891
      "\xdb7b",      # CPData Name: surrpair n:892
      "\xdb7c",      # CPData Name: surrpair n:893
      "\xdb7d",      # CPData Name: surrpair n:894
      "\xdb7e",      # CPData Name: surrpair n:895
      "\xdb7f",      # CPData Name: surrpair n:896
      "\xdb80",      # CPData Name: surrpair n:897
      "\xdb81",      # CPData Name: surrpair n:898
      "\xdb82",      # CPData Name: surrpair n:899
      "\xdb83",      # CPData Name: surrpair n:900
      "\xdb84",      # CPData Name: surrpair n:901
      "\xdb85",      # CPData Name: surrpair n:902
      "\xdb86",      # CPData Name: surrpair n:903
      "\xdb87",      # CPData Name: surrpair n:904
      "\xdb88",      # CPData Name: surrpair n:905
      "\xdb89",      # CPData Name: surrpair n:906
      "\xdb8a",      # CPData Name: surrpair n:907
      "\xdb8b",      # CPData Name: surrpair n:908
      "\xdb8c",      # CPData Name: surrpair n:909
      "\xdb8d",      # CPData Name: surrpair n:910
      "\xdb8e",      # CPData Name: surrpair n:911
      "\xdb8f",      # CPData Name: surrpair n:912
      "\xdb90",      # CPData Name: surrpair n:913
      "\xdb91",      # CPData Name: surrpair n:914
      "\xdb92",      # CPData Name: surrpair n:915
      "\xdb93",      # CPData Name: surrpair n:916
      "\xdb94",      # CPData Name: surrpair n:917
      "\xdb95",      # CPData Name: surrpair n:918
      "\xdb96",      # CPData Name: surrpair n:919
      "\xdb97",      # CPData Name: surrpair n:920
      "\xdb98",      # CPData Name: surrpair n:921
      "\xdb99",      # CPData Name: surrpair n:922
      "\xdb9a",      # CPData Name: surrpair n:923
      "\xdb9b",      # CPData Name: surrpair n:924
      "\xdb9c",      # CPData Name: surrpair n:925
      "\xdb9d",      # CPData Name: surrpair n:926
      "\xdb9e",      # CPData Name: surrpair n:927
      "\xdb9f",      # CPData Name: surrpair n:928
      "\xdba0",      # CPData Name: surrpair n:929
      "\xdba1",      # CPData Name: surrpair n:930
      "\xdba2",      # CPData Name: surrpair n:931
      "\xdba3",      # CPData Name: surrpair n:932
      "\xdba4",      # CPData Name: surrpair n:933
      "\xdba5",      # CPData Name: surrpair n:934
      "\xdba6",      # CPData Name: surrpair n:935
      "\xdba7",      # CPData Name: surrpair n:936
      "\xdba8",      # CPData Name: surrpair n:937
      "\xdba9",      # CPData Name: surrpair n:938
      "\xdbaa",      # CPData Name: surrpair n:939
      "\xdbab",      # CPData Name: surrpair n:940
      "\xdbac",      # CPData Name: surrpair n:941
      "\xdbad",      # CPData Name: surrpair n:942
      "\xdbae",      # CPData Name: surrpair n:943
      "\xdbaf",      # CPData Name: surrpair n:944
      "\xdbb0",      # CPData Name: surrpair n:945
      "\xdbb1",      # CPData Name: surrpair n:946
      "\xdbb2",      # CPData Name: surrpair n:947
      "\xdbb3",      # CPData Name: surrpair n:948
      "\xdbb4",      # CPData Name: surrpair n:949
      "\xdbb5",      # CPData Name: surrpair n:950
      "\xdbb6",      # CPData Name: surrpair n:951
      "\xdbb7",      # CPData Name: surrpair n:952
      "\xdbb8",      # CPData Name: surrpair n:953
      "\xdbb9",      # CPData Name: surrpair n:954
      "\xdbba",      # CPData Name: surrpair n:955
      "\xdbbb",      # CPData Name: surrpair n:956
      "\xdbbc",      # CPData Name: surrpair n:957
      "\xdbbd",      # CPData Name: surrpair n:958
      "\xdbbe",      # CPData Name: surrpair n:959
      "\xdbbf",      # CPData Name: surrpair n:960
      "\xdbc0",      # CPData Name: surrpair n:961
      "\xdbc1",      # CPData Name: surrpair n:962
      "\xdbc2",      # CPData Name: surrpair n:963
      "\xdbc3",      # CPData Name: surrpair n:964
      "\xdbc4",      # CPData Name: surrpair n:965
      "\xdbc5",      # CPData Name: surrpair n:966
      "\xdbc6",      # CPData Name: surrpair n:967
      "\xdbc7",      # CPData Name: surrpair n:968
      "\xdbc8",      # CPData Name: surrpair n:969
      "\xdbc9",      # CPData Name: surrpair n:970
      "\xdbca",      # CPData Name: surrpair n:971
      "\xdbcb",      # CPData Name: surrpair n:972
      "\xdbcc",      # CPData Name: surrpair n:973
      "\xdbcd",      # CPData Name: surrpair n:974
      "\xdbce",      # CPData Name: surrpair n:975
      "\xdbcf",      # CPData Name: surrpair n:976
      "\xdbd0",      # CPData Name: surrpair n:977
      "\xdbd1",      # CPData Name: surrpair n:978
      "\xdbd2",      # CPData Name: surrpair n:979
      "\xdbd3",      # CPData Name: surrpair n:980
      "\xdbd4",      # CPData Name: surrpair n:981
      "\xdbd5",      # CPData Name: surrpair n:982
      "\xdbd6",      # CPData Name: surrpair n:983
      "\xdbd7",      # CPData Name: surrpair n:984
      "\xdbd8",      # CPData Name: surrpair n:985
      "\xdbd9",      # CPData Name: surrpair n:986
      "\xdbda",      # CPData Name: surrpair n:987
      "\xdbdb",      # CPData Name: surrpair n:988
      "\xdbdc",      # CPData Name: surrpair n:989
      "\xdbdd",      # CPData Name: surrpair n:990
      "\xdbde",      # CPData Name: surrpair n:991
      "\xdbdf",      # CPData Name: surrpair n:992
      "\xdbe0",      # CPData Name: surrpair n:993
      "\xdbe1",      # CPData Name: surrpair n:994
      "\xdbe2",      # CPData Name: surrpair n:995
      "\xdbe3",      # CPData Name: surrpair n:996
      "\xdbe4",      # CPData Name: surrpair n:997
      "\xdbe5",      # CPData Name: surrpair n:998
      "\xdbe6",      # CPData Name: surrpair n:999
      "\xdbe7",      # CPData Name: surrpair n:1000
      "\xdbe8",      # CPData Name: surrpair n:1001
      "\xdbe9",      # CPData Name: surrpair n:1002
      "\xdbea",      # CPData Name: surrpair n:1003
      "\xdbeb",      # CPData Name: surrpair n:1004
      "\xdbec",      # CPData Name: surrpair n:1005
      "\xdbed",      # CPData Name: surrpair n:1006
      "\xdbee",      # CPData Name: surrpair n:1007
      "\xdbef",      # CPData Name: surrpair n:1008
      "\xdbf0",      # CPData Name: surrpair n:1009
      "\xdbf1",      # CPData Name: surrpair n:1010
      "\xdbf2",      # CPData Name: surrpair n:1011
      "\xdbf3",      # CPData Name: surrpair n:1012
      "\xdbf4",      # CPData Name: surrpair n:1013
      "\xdbf5",      # CPData Name: surrpair n:1014
      "\xdbf6",      # CPData Name: surrpair n:1015
      "\xdbf7",      # CPData Name: surrpair n:1016
      "\xdbf8",      # CPData Name: surrpair n:1017
      "\xdbf9",      # CPData Name: surrpair n:1018
      "\xdbfa",      # CPData Name: surrpair n:1019
      "\xdbfb",      # CPData Name: surrpair n:1020
      "\xdbfc",      # CPData Name: surrpair n:1021
      "\xdbfd",      # CPData Name: surrpair n:1022
      "\xdbfe",      # CPData Name: surrpair n:1023
      "\xdbff",      # CPData Name: surrpair n:1024
      "\xdc00",      # CPData Name: surrpair n:1025
      "\xdc01",      # CPData Name: surrpair n:1026
      "\xdc02",      # CPData Name: surrpair n:1027
      "\xdc03",      # CPData Name: surrpair n:1028
      "\xdc04",      # CPData Name: surrpair n:1029
      "\xdc05",      # CPData Name: surrpair n:1030
      "\xdc06",      # CPData Name: surrpair n:1031
      "\xdc07",      # CPData Name: surrpair n:1032
      "\xdc08",      # CPData Name: surrpair n:1033
      "\xdc09",      # CPData Name: surrpair n:1034
      "\xdc0a",      # CPData Name: surrpair n:1035
      "\xdc0b",      # CPData Name: surrpair n:1036
      "\xdc0c",      # CPData Name: surrpair n:1037
      "\xdc0d",      # CPData Name: surrpair n:1038
      "\xdc0e",      # CPData Name: surrpair n:1039
      "\xdc0f",      # CPData Name: surrpair n:1040
      "\xdc10",      # CPData Name: surrpair n:1041
      "\xdc11",      # CPData Name: surrpair n:1042
      "\xdc12",      # CPData Name: surrpair n:1043
      "\xdc13",      # CPData Name: surrpair n:1044
      "\xdc14",      # CPData Name: surrpair n:1045
      "\xdc15",      # CPData Name: surrpair n:1046
      "\xdc16",      # CPData Name: surrpair n:1047
      "\xdc17",      # CPData Name: surrpair n:1048
      "\xdc18",      # CPData Name: surrpair n:1049
      "\xdc19",      # CPData Name: surrpair n:1050
      "\xdc1a",      # CPData Name: surrpair n:1051
      "\xdc1b",      # CPData Name: surrpair n:1052
      "\xdc1c",      # CPData Name: surrpair n:1053
      "\xdc1d",      # CPData Name: surrpair n:1054
      "\xdc1e",      # CPData Name: surrpair n:1055
      "\xdc1f",      # CPData Name: surrpair n:1056
      "\xdc20",      # CPData Name: surrpair n:1057
      "\xdc21",      # CPData Name: surrpair n:1058
      "\xdc22",      # CPData Name: surrpair n:1059
      "\xdc23",      # CPData Name: surrpair n:1060
      "\xdc24",      # CPData Name: surrpair n:1061
      "\xdc25",      # CPData Name: surrpair n:1062
      "\xdc26",      # CPData Name: surrpair n:1063
      "\xdc27",      # CPData Name: surrpair n:1064
      "\xdc28",      # CPData Name: surrpair n:1065
      "\xdc29",      # CPData Name: surrpair n:1066
      "\xdc2a",      # CPData Name: surrpair n:1067
      "\xdc2b",      # CPData Name: surrpair n:1068
      "\xdc2c",      # CPData Name: surrpair n:1069
      "\xdc2d",      # CPData Name: surrpair n:1070
      "\xdc2e",      # CPData Name: surrpair n:1071
      "\xdc2f",      # CPData Name: surrpair n:1072
      "\xdc30",      # CPData Name: surrpair n:1073
      "\xdc31",      # CPData Name: surrpair n:1074
      "\xdc32",      # CPData Name: surrpair n:1075
      "\xdc33",      # CPData Name: surrpair n:1076
      "\xdc34",      # CPData Name: surrpair n:1077
      "\xdc35",      # CPData Name: surrpair n:1078
      "\xdc36",      # CPData Name: surrpair n:1079
      "\xdc37",      # CPData Name: surrpair n:1080
      "\xdc38",      # CPData Name: surrpair n:1081
      "\xdc39",      # CPData Name: surrpair n:1082
      "\xdc3a",      # CPData Name: surrpair n:1083
      "\xdc3b",      # CPData Name: surrpair n:1084
      "\xdc3c",      # CPData Name: surrpair n:1085
      "\xdc3d",      # CPData Name: surrpair n:1086
      "\xdc3e",      # CPData Name: surrpair n:1087
      "\xdc3f",      # CPData Name: surrpair n:1088
      "\xdc40",      # CPData Name: surrpair n:1089
      "\xdc41",      # CPData Name: surrpair n:1090
      "\xdc42",      # CPData Name: surrpair n:1091
      "\xdc43",      # CPData Name: surrpair n:1092
      "\xdc44",      # CPData Name: surrpair n:1093
      "\xdc45",      # CPData Name: surrpair n:1094
      "\xdc46",      # CPData Name: surrpair n:1095
      "\xdc47",      # CPData Name: surrpair n:1096
      "\xdc48",      # CPData Name: surrpair n:1097
      "\xdc49",      # CPData Name: surrpair n:1098
      "\xdc4a",      # CPData Name: surrpair n:1099
      "\xdc4b",      # CPData Name: surrpair n:1100
      "\xdc4c",      # CPData Name: surrpair n:1101
      "\xdc4d",      # CPData Name: surrpair n:1102
      "\xdc4e",      # CPData Name: surrpair n:1103
      "\xdc4f",      # CPData Name: surrpair n:1104
      "\xdc50",      # CPData Name: surrpair n:1105
      "\xdc51",      # CPData Name: surrpair n:1106
      "\xdc52",      # CPData Name: surrpair n:1107
      "\xdc53",      # CPData Name: surrpair n:1108
      "\xdc54",      # CPData Name: surrpair n:1109
      "\xdc55",      # CPData Name: surrpair n:1110
      "\xdc56",      # CPData Name: surrpair n:1111
      "\xdc57",      # CPData Name: surrpair n:1112
      "\xdc58",      # CPData Name: surrpair n:1113
      "\xdc59",      # CPData Name: surrpair n:1114
      "\xdc5a",      # CPData Name: surrpair n:1115
      "\xdc5b",      # CPData Name: surrpair n:1116
      "\xdc5c",      # CPData Name: surrpair n:1117
      "\xdc5d",      # CPData Name: surrpair n:1118
      "\xdc5e",      # CPData Name: surrpair n:1119
      "\xdc5f",      # CPData Name: surrpair n:1120
      "\xdc60",      # CPData Name: surrpair n:1121
      "\xdc61",      # CPData Name: surrpair n:1122
      "\xdc62",      # CPData Name: surrpair n:1123
      "\xdc63",      # CPData Name: surrpair n:1124
      "\xdc64",      # CPData Name: surrpair n:1125
      "\xdc65",      # CPData Name: surrpair n:1126
      "\xdc66",      # CPData Name: surrpair n:1127
      "\xdc67",      # CPData Name: surrpair n:1128
      "\xdc68",      # CPData Name: surrpair n:1129
      "\xdc69",      # CPData Name: surrpair n:1130
      "\xdc6a",      # CPData Name: surrpair n:1131
      "\xdc6b",      # CPData Name: surrpair n:1132
      "\xdc6c",      # CPData Name: surrpair n:1133
      "\xdc6d",      # CPData Name: surrpair n:1134
      "\xdc6e",      # CPData Name: surrpair n:1135
      "\xdc6f",      # CPData Name: surrpair n:1136
      "\xdc70",      # CPData Name: surrpair n:1137
      "\xdc71",      # CPData Name: surrpair n:1138
      "\xdc72",      # CPData Name: surrpair n:1139
      "\xdc73",      # CPData Name: surrpair n:1140
      "\xdc74",      # CPData Name: surrpair n:1141
      "\xdc75",      # CPData Name: surrpair n:1142
      "\xdc76",      # CPData Name: surrpair n:1143
      "\xdc77",      # CPData Name: surrpair n:1144
      "\xdc78",      # CPData Name: surrpair n:1145
      "\xdc79",      # CPData Name: surrpair n:1146
      "\xdc7a",      # CPData Name: surrpair n:1147
      "\xdc7b",      # CPData Name: surrpair n:1148
      "\xdc7c",      # CPData Name: surrpair n:1149
      "\xdc7d",      # CPData Name: surrpair n:1150
      "\xdc7e",      # CPData Name: surrpair n:1151
      "\xdc7f",      # CPData Name: surrpair n:1152
      "\xdc80",      # CPData Name: surrpair n:1153
      "\xdc81",      # CPData Name: surrpair n:1154
      "\xdc82",      # CPData Name: surrpair n:1155
      "\xdc83",      # CPData Name: surrpair n:1156
      "\xdc84",      # CPData Name: surrpair n:1157
      "\xdc85",      # CPData Name: surrpair n:1158
      "\xdc86",      # CPData Name: surrpair n:1159
      "\xdc87",      # CPData Name: surrpair n:1160
      "\xdc88",      # CPData Name: surrpair n:1161
      "\xdc89",      # CPData Name: surrpair n:1162
      "\xdc8a",      # CPData Name: surrpair n:1163
      "\xdc8b",      # CPData Name: surrpair n:1164
      "\xdc8c",      # CPData Name: surrpair n:1165
      "\xdc8d",      # CPData Name: surrpair n:1166
      "\xdc8e",      # CPData Name: surrpair n:1167
      "\xdc8f",      # CPData Name: surrpair n:1168
      "\xdc90",      # CPData Name: surrpair n:1169
      "\xdc91",      # CPData Name: surrpair n:1170
      "\xdc92",      # CPData Name: surrpair n:1171
      "\xdc93",      # CPData Name: surrpair n:1172
      "\xdc94",      # CPData Name: surrpair n:1173
      "\xdc95",      # CPData Name: surrpair n:1174
      "\xdc96",      # CPData Name: surrpair n:1175
      "\xdc97",      # CPData Name: surrpair n:1176
      "\xdc98",      # CPData Name: surrpair n:1177
      "\xdc99",      # CPData Name: surrpair n:1178
      "\xdc9a",      # CPData Name: surrpair n:1179
      "\xdc9b",      # CPData Name: surrpair n:1180
      "\xdc9c",      # CPData Name: surrpair n:1181
      "\xdc9d",      # CPData Name: surrpair n:1182
      "\xdc9e",      # CPData Name: surrpair n:1183
      "\xdc9f",      # CPData Name: surrpair n:1184
      "\xdca0",      # CPData Name: surrpair n:1185
      "\xdca1",      # CPData Name: surrpair n:1186
      "\xdca2",      # CPData Name: surrpair n:1187
      "\xdca3",      # CPData Name: surrpair n:1188
      "\xdca4",      # CPData Name: surrpair n:1189
      "\xdca5",      # CPData Name: surrpair n:1190
      "\xdca6",      # CPData Name: surrpair n:1191
      "\xdca7",      # CPData Name: surrpair n:1192
      "\xdca8",      # CPData Name: surrpair n:1193
      "\xdca9",      # CPData Name: surrpair n:1194
      "\xdcaa",      # CPData Name: surrpair n:1195
      "\xdcab",      # CPData Name: surrpair n:1196
      "\xdcac",      # CPData Name: surrpair n:1197
      "\xdcad",      # CPData Name: surrpair n:1198
      "\xdcae",      # CPData Name: surrpair n:1199
      "\xdcaf",      # CPData Name: surrpair n:1200
      "\xdcb0",      # CPData Name: surrpair n:1201
      "\xdcb1",      # CPData Name: surrpair n:1202
      "\xdcb2",      # CPData Name: surrpair n:1203
      "\xdcb3",      # CPData Name: surrpair n:1204
      "\xdcb4",      # CPData Name: surrpair n:1205
      "\xdcb5",      # CPData Name: surrpair n:1206
      "\xdcb6",      # CPData Name: surrpair n:1207
      "\xdcb7",      # CPData Name: surrpair n:1208
      "\xdcb8",      # CPData Name: surrpair n:1209
      "\xdcb9",      # CPData Name: surrpair n:1210
      "\xdcba",      # CPData Name: surrpair n:1211
      "\xdcbb",      # CPData Name: surrpair n:1212
      "\xdcbc",      # CPData Name: surrpair n:1213
      "\xdcbd",      # CPData Name: surrpair n:1214
      "\xdcbe",      # CPData Name: surrpair n:1215
      "\xdcbf",      # CPData Name: surrpair n:1216
      "\xdcc0",      # CPData Name: surrpair n:1217
      "\xdcc1",      # CPData Name: surrpair n:1218
      "\xdcc2",      # CPData Name: surrpair n:1219
      "\xdcc3",      # CPData Name: surrpair n:1220
      "\xdcc4",      # CPData Name: surrpair n:1221
      "\xdcc5",      # CPData Name: surrpair n:1222
      "\xdcc6",      # CPData Name: surrpair n:1223
      "\xdcc7",      # CPData Name: surrpair n:1224
      "\xdcc8",      # CPData Name: surrpair n:1225
      "\xdcc9",      # CPData Name: surrpair n:1226
      "\xdcca",      # CPData Name: surrpair n:1227
      "\xdccb",      # CPData Name: surrpair n:1228
      "\xdccc",      # CPData Name: surrpair n:1229
      "\xdccd",      # CPData Name: surrpair n:1230
      "\xdcce",      # CPData Name: surrpair n:1231
      "\xdccf",      # CPData Name: surrpair n:1232
      "\xdcd0",      # CPData Name: surrpair n:1233
      "\xdcd1",      # CPData Name: surrpair n:1234
      "\xdcd2",      # CPData Name: surrpair n:1235
      "\xdcd3",      # CPData Name: surrpair n:1236
      "\xdcd4",      # CPData Name: surrpair n:1237
      "\xdcd5",      # CPData Name: surrpair n:1238
      "\xdcd6",      # CPData Name: surrpair n:1239
      "\xdcd7",      # CPData Name: surrpair n:1240
      "\xdcd8",      # CPData Name: surrpair n:1241
      "\xdcd9",      # CPData Name: surrpair n:1242
      "\xdcda",      # CPData Name: surrpair n:1243
      "\xdcdb",      # CPData Name: surrpair n:1244
      "\xdcdc",      # CPData Name: surrpair n:1245
      "\xdcdd",      # CPData Name: surrpair n:1246
      "\xdcde",      # CPData Name: surrpair n:1247
      "\xdcdf",      # CPData Name: surrpair n:1248
      "\xdce0",      # CPData Name: surrpair n:1249
      "\xdce1",      # CPData Name: surrpair n:1250
      "\xdce2",      # CPData Name: surrpair n:1251
      "\xdce3",      # CPData Name: surrpair n:1252
      "\xdce4",      # CPData Name: surrpair n:1253
      "\xdce5",      # CPData Name: surrpair n:1254
      "\xdce6",      # CPData Name: surrpair n:1255
      "\xdce7",      # CPData Name: surrpair n:1256
      "\xdce8",      # CPData Name: surrpair n:1257
      "\xdce9",      # CPData Name: surrpair n:1258
      "\xdcea",      # CPData Name: surrpair n:1259
      "\xdceb",      # CPData Name: surrpair n:1260
      "\xdcec",      # CPData Name: surrpair n:1261
      "\xdced",      # CPData Name: surrpair n:1262
      "\xdcee",      # CPData Name: surrpair n:1263
      "\xdcef",      # CPData Name: surrpair n:1264
      "\xdcf0",      # CPData Name: surrpair n:1265
      "\xdcf1",      # CPData Name: surrpair n:1266
      "\xdcf2",      # CPData Name: surrpair n:1267
      "\xdcf3",      # CPData Name: surrpair n:1268
      "\xdcf4",      # CPData Name: surrpair n:1269
      "\xdcf5",      # CPData Name: surrpair n:1270
      "\xdcf6",      # CPData Name: surrpair n:1271
      "\xdcf7",      # CPData Name: surrpair n:1272
      "\xdcf8",      # CPData Name: surrpair n:1273
      "\xdcf9",      # CPData Name: surrpair n:1274
      "\xdcfa",      # CPData Name: surrpair n:1275
      "\xdcfb",      # CPData Name: surrpair n:1276
      "\xdcfc",      # CPData Name: surrpair n:1277
      "\xdcfd",      # CPData Name: surrpair n:1278
      "\xdcfe",      # CPData Name: surrpair n:1279
      "\xdcff",      # CPData Name: surrpair n:1280
      "\xdd00",      # CPData Name: surrpair n:1281
      "\xdd01",      # CPData Name: surrpair n:1282
      "\xdd02",      # CPData Name: surrpair n:1283
      "\xdd03",      # CPData Name: surrpair n:1284
      "\xdd04",      # CPData Name: surrpair n:1285
      "\xdd05",      # CPData Name: surrpair n:1286
      "\xdd06",      # CPData Name: surrpair n:1287
      "\xdd07",      # CPData Name: surrpair n:1288
      "\xdd08",      # CPData Name: surrpair n:1289
      "\xdd09",      # CPData Name: surrpair n:1290
      "\xdd0a",      # CPData Name: surrpair n:1291
      "\xdd0b",      # CPData Name: surrpair n:1292
      "\xdd0c",      # CPData Name: surrpair n:1293
      "\xdd0d",      # CPData Name: surrpair n:1294
      "\xdd0e",      # CPData Name: surrpair n:1295
      "\xdd0f",      # CPData Name: surrpair n:1296
      "\xdd10",      # CPData Name: surrpair n:1297
      "\xdd11",      # CPData Name: surrpair n:1298
      "\xdd12",      # CPData Name: surrpair n:1299
      "\xdd13",      # CPData Name: surrpair n:1300
      "\xdd14",      # CPData Name: surrpair n:1301
      "\xdd15",      # CPData Name: surrpair n:1302
      "\xdd16",      # CPData Name: surrpair n:1303
      "\xdd17",      # CPData Name: surrpair n:1304
      "\xdd18",      # CPData Name: surrpair n:1305
      "\xdd19",      # CPData Name: surrpair n:1306
      "\xdd1a",      # CPData Name: surrpair n:1307
      "\xdd1b",      # CPData Name: surrpair n:1308
      "\xdd1c",      # CPData Name: surrpair n:1309
      "\xdd1d",      # CPData Name: surrpair n:1310
      "\xdd1e",      # CPData Name: surrpair n:1311
      "\xdd1f",      # CPData Name: surrpair n:1312
      "\xdd20",      # CPData Name: surrpair n:1313
      "\xdd21",      # CPData Name: surrpair n:1314
      "\xdd22",      # CPData Name: surrpair n:1315
      "\xdd23",      # CPData Name: surrpair n:1316
      "\xdd24",      # CPData Name: surrpair n:1317
      "\xdd25",      # CPData Name: surrpair n:1318
      "\xdd26",      # CPData Name: surrpair n:1319
      "\xdd27",      # CPData Name: surrpair n:1320
      "\xdd28",      # CPData Name: surrpair n:1321
      "\xdd29",      # CPData Name: surrpair n:1322
      "\xdd2a",      # CPData Name: surrpair n:1323
      "\xdd2b",      # CPData Name: surrpair n:1324
      "\xdd2c",      # CPData Name: surrpair n:1325
      "\xdd2d",      # CPData Name: surrpair n:1326
      "\xdd2e",      # CPData Name: surrpair n:1327
      "\xdd2f",      # CPData Name: surrpair n:1328
      "\xdd30",      # CPData Name: surrpair n:1329
      "\xdd31",      # CPData Name: surrpair n:1330
      "\xdd32",      # CPData Name: surrpair n:1331
      "\xdd33",      # CPData Name: surrpair n:1332
      "\xdd34",      # CPData Name: surrpair n:1333
      "\xdd35",      # CPData Name: surrpair n:1334
      "\xdd36",      # CPData Name: surrpair n:1335
      "\xdd37",      # CPData Name: surrpair n:1336
      "\xdd38",      # CPData Name: surrpair n:1337
      "\xdd39",      # CPData Name: surrpair n:1338
      "\xdd3a",      # CPData Name: surrpair n:1339
      "\xdd3b",      # CPData Name: surrpair n:1340
      "\xdd3c",      # CPData Name: surrpair n:1341
      "\xdd3d",      # CPData Name: surrpair n:1342
      "\xdd3e",      # CPData Name: surrpair n:1343
      "\xdd3f",      # CPData Name: surrpair n:1344
      "\xdd40",      # CPData Name: surrpair n:1345
      "\xdd41",      # CPData Name: surrpair n:1346
      "\xdd42",      # CPData Name: surrpair n:1347
      "\xdd43",      # CPData Name: surrpair n:1348
      "\xdd44",      # CPData Name: surrpair n:1349
      "\xdd45",      # CPData Name: surrpair n:1350
      "\xdd46",      # CPData Name: surrpair n:1351
      "\xdd47",      # CPData Name: surrpair n:1352
      "\xdd48",      # CPData Name: surrpair n:1353
      "\xdd49",      # CPData Name: surrpair n:1354
      "\xdd4a",      # CPData Name: surrpair n:1355
      "\xdd4b",      # CPData Name: surrpair n:1356
      "\xdd4c",      # CPData Name: surrpair n:1357
      "\xdd4d",      # CPData Name: surrpair n:1358
      "\xdd4e",      # CPData Name: surrpair n:1359
      "\xdd4f",      # CPData Name: surrpair n:1360
      "\xdd50",      # CPData Name: surrpair n:1361
      "\xdd51",      # CPData Name: surrpair n:1362
      "\xdd52",      # CPData Name: surrpair n:1363
      "\xdd53",      # CPData Name: surrpair n:1364
      "\xdd54",      # CPData Name: surrpair n:1365
      "\xdd55",      # CPData Name: surrpair n:1366
      "\xdd56",      # CPData Name: surrpair n:1367
      "\xdd57",      # CPData Name: surrpair n:1368
      "\xdd58",      # CPData Name: surrpair n:1369
      "\xdd59",      # CPData Name: surrpair n:1370
      "\xdd5a",      # CPData Name: surrpair n:1371
      "\xdd5b",      # CPData Name: surrpair n:1372
      "\xdd5c",      # CPData Name: surrpair n:1373
      "\xdd5d",      # CPData Name: surrpair n:1374
      "\xdd5e",      # CPData Name: surrpair n:1375
      "\xdd5f",      # CPData Name: surrpair n:1376
      "\xdd60",      # CPData Name: surrpair n:1377
      "\xdd61",      # CPData Name: surrpair n:1378
      "\xdd62",      # CPData Name: surrpair n:1379
      "\xdd63",      # CPData Name: surrpair n:1380
      "\xdd64",      # CPData Name: surrpair n:1381
      "\xdd65",      # CPData Name: surrpair n:1382
      "\xdd66",      # CPData Name: surrpair n:1383
      "\xdd67",      # CPData Name: surrpair n:1384
      "\xdd68",      # CPData Name: surrpair n:1385
      "\xdd69",      # CPData Name: surrpair n:1386
      "\xdd6a",      # CPData Name: surrpair n:1387
      "\xdd6b",      # CPData Name: surrpair n:1388
      "\xdd6c",      # CPData Name: surrpair n:1389
      "\xdd6d",      # CPData Name: surrpair n:1390
      "\xdd6e",      # CPData Name: surrpair n:1391
      "\xdd6f",      # CPData Name: surrpair n:1392
      "\xdd70",      # CPData Name: surrpair n:1393
      "\xdd71",      # CPData Name: surrpair n:1394
      "\xdd72",      # CPData Name: surrpair n:1395
      "\xdd73",      # CPData Name: surrpair n:1396
      "\xdd74",      # CPData Name: surrpair n:1397
      "\xdd75",      # CPData Name: surrpair n:1398
      "\xdd76",      # CPData Name: surrpair n:1399
      "\xdd77",      # CPData Name: surrpair n:1400
      "\xdd78",      # CPData Name: surrpair n:1401
      "\xdd79",      # CPData Name: surrpair n:1402
      "\xdd7a",      # CPData Name: surrpair n:1403
      "\xdd7b",      # CPData Name: surrpair n:1404
      "\xdd7c",      # CPData Name: surrpair n:1405
      "\xdd7d",      # CPData Name: surrpair n:1406
      "\xdd7e",      # CPData Name: surrpair n:1407
      "\xdd7f",      # CPData Name: surrpair n:1408
      "\xdd80",      # CPData Name: surrpair n:1409
      "\xdd81",      # CPData Name: surrpair n:1410
      "\xdd82",      # CPData Name: surrpair n:1411
      "\xdd83",      # CPData Name: surrpair n:1412
      "\xdd84",      # CPData Name: surrpair n:1413
      "\xdd85",      # CPData Name: surrpair n:1414
      "\xdd86",      # CPData Name: surrpair n:1415
      "\xdd87",      # CPData Name: surrpair n:1416
      "\xdd88",      # CPData Name: surrpair n:1417
      "\xdd89",      # CPData Name: surrpair n:1418
      "\xdd8a",      # CPData Name: surrpair n:1419
      "\xdd8b",      # CPData Name: surrpair n:1420
      "\xdd8c",      # CPData Name: surrpair n:1421
      "\xdd8d",      # CPData Name: surrpair n:1422
      "\xdd8e",      # CPData Name: surrpair n:1423
      "\xdd8f",      # CPData Name: surrpair n:1424
      "\xdd90",      # CPData Name: surrpair n:1425
      "\xdd91",      # CPData Name: surrpair n:1426
      "\xdd92",      # CPData Name: surrpair n:1427
      "\xdd93",      # CPData Name: surrpair n:1428
      "\xdd94",      # CPData Name: surrpair n:1429
      "\xdd95",      # CPData Name: surrpair n:1430
      "\xdd96",      # CPData Name: surrpair n:1431
      "\xdd97",      # CPData Name: surrpair n:1432
      "\xdd98",      # CPData Name: surrpair n:1433
      "\xdd99",      # CPData Name: surrpair n:1434
      "\xdd9a",      # CPData Name: surrpair n:1435
      "\xdd9b",      # CPData Name: surrpair n:1436
      "\xdd9c",      # CPData Name: surrpair n:1437
      "\xdd9d",      # CPData Name: surrpair n:1438
      "\xdd9e",      # CPData Name: surrpair n:1439
      "\xdd9f",      # CPData Name: surrpair n:1440
      "\xdda0",      # CPData Name: surrpair n:1441
      "\xdda1",      # CPData Name: surrpair n:1442
      "\xdda2",      # CPData Name: surrpair n:1443
      "\xdda3",      # CPData Name: surrpair n:1444
      "\xdda4",      # CPData Name: surrpair n:1445
      "\xdda5",      # CPData Name: surrpair n:1446
      "\xdda6",      # CPData Name: surrpair n:1447
      "\xdda7",      # CPData Name: surrpair n:1448
      "\xdda8",      # CPData Name: surrpair n:1449
      "\xdda9",      # CPData Name: surrpair n:1450
      "\xddaa",      # CPData Name: surrpair n:1451
      "\xddab",      # CPData Name: surrpair n:1452
      "\xddac",      # CPData Name: surrpair n:1453
      "\xddad",      # CPData Name: surrpair n:1454
      "\xddae",      # CPData Name: surrpair n:1455
      "\xddaf",      # CPData Name: surrpair n:1456
      "\xddb0",      # CPData Name: surrpair n:1457
      "\xddb1",      # CPData Name: surrpair n:1458
      "\xddb2",      # CPData Name: surrpair n:1459
      "\xddb3",      # CPData Name: surrpair n:1460
      "\xddb4",      # CPData Name: surrpair n:1461
      "\xddb5",      # CPData Name: surrpair n:1462
      "\xddb6",      # CPData Name: surrpair n:1463
      "\xddb7",      # CPData Name: surrpair n:1464
      "\xddb8",      # CPData Name: surrpair n:1465
      "\xddb9",      # CPData Name: surrpair n:1466
      "\xddba",      # CPData Name: surrpair n:1467
      "\xddbb",      # CPData Name: surrpair n:1468
      "\xddbc",      # CPData Name: surrpair n:1469
      "\xddbd",      # CPData Name: surrpair n:1470
      "\xddbe",      # CPData Name: surrpair n:1471
      "\xddbf",      # CPData Name: surrpair n:1472
      "\xddc0",      # CPData Name: surrpair n:1473
      "\xddc1",      # CPData Name: surrpair n:1474
      "\xddc2",      # CPData Name: surrpair n:1475
      "\xddc3",      # CPData Name: surrpair n:1476
      "\xddc4",      # CPData Name: surrpair n:1477
      "\xddc5",      # CPData Name: surrpair n:1478
      "\xddc6",      # CPData Name: surrpair n:1479
      "\xddc7",      # CPData Name: surrpair n:1480
      "\xddc8",      # CPData Name: surrpair n:1481
      "\xddc9",      # CPData Name: surrpair n:1482
      "\xddca",      # CPData Name: surrpair n:1483
      "\xddcb",      # CPData Name: surrpair n:1484
      "\xddcc",      # CPData Name: surrpair n:1485
      "\xddcd",      # CPData Name: surrpair n:1486
      "\xddce",      # CPData Name: surrpair n:1487
      "\xddcf",      # CPData Name: surrpair n:1488
      "\xddd0",      # CPData Name: surrpair n:1489
      "\xddd1",      # CPData Name: surrpair n:1490
      "\xddd2",      # CPData Name: surrpair n:1491
      "\xddd3",      # CPData Name: surrpair n:1492
      "\xddd4",      # CPData Name: surrpair n:1493
      "\xddd5",      # CPData Name: surrpair n:1494
      "\xddd6",      # CPData Name: surrpair n:1495
      "\xddd7",      # CPData Name: surrpair n:1496
      "\xddd8",      # CPData Name: surrpair n:1497
      "\xddd9",      # CPData Name: surrpair n:1498
      "\xddda",      # CPData Name: surrpair n:1499
      "\xdddb",      # CPData Name: surrpair n:1500
      "\xdddc",      # CPData Name: surrpair n:1501
      "\xdddd",      # CPData Name: surrpair n:1502
      "\xddde",      # CPData Name: surrpair n:1503
      "\xdddf",      # CPData Name: surrpair n:1504
      "\xdde0",      # CPData Name: surrpair n:1505
      "\xdde1",      # CPData Name: surrpair n:1506
      "\xdde2",      # CPData Name: surrpair n:1507
      "\xdde3",      # CPData Name: surrpair n:1508
      "\xdde4",      # CPData Name: surrpair n:1509
      "\xdde5",      # CPData Name: surrpair n:1510
      "\xdde6",      # CPData Name: surrpair n:1511
      "\xdde7",      # CPData Name: surrpair n:1512
      "\xdde8",      # CPData Name: surrpair n:1513
      "\xdde9",      # CPData Name: surrpair n:1514
      "\xddea",      # CPData Name: surrpair n:1515
      "\xddeb",      # CPData Name: surrpair n:1516
      "\xddec",      # CPData Name: surrpair n:1517
      "\xdded",      # CPData Name: surrpair n:1518
      "\xddee",      # CPData Name: surrpair n:1519
      "\xddef",      # CPData Name: surrpair n:1520
      "\xddf0",      # CPData Name: surrpair n:1521
      "\xddf1",      # CPData Name: surrpair n:1522
      "\xddf2",      # CPData Name: surrpair n:1523
      "\xddf3",      # CPData Name: surrpair n:1524
      "\xddf4",      # CPData Name: surrpair n:1525
      "\xddf5",      # CPData Name: surrpair n:1526
      "\xddf6",      # CPData Name: surrpair n:1527
      "\xddf7",      # CPData Name: surrpair n:1528
      "\xddf8",      # CPData Name: surrpair n:1529
      "\xddf9",      # CPData Name: surrpair n:1530
      "\xddfa",      # CPData Name: surrpair n:1531
      "\xddfb",      # CPData Name: surrpair n:1532
      "\xddfc",      # CPData Name: surrpair n:1533
      "\xddfd",      # CPData Name: surrpair n:1534
      "\xddfe",      # CPData Name: surrpair n:1535
      "\xddff",      # CPData Name: surrpair n:1536
      "\xde00",      # CPData Name: surrpair n:1537
      "\xde01",      # CPData Name: surrpair n:1538
      "\xde02",      # CPData Name: surrpair n:1539
      "\xde03",      # CPData Name: surrpair n:1540
      "\xde04",      # CPData Name: surrpair n:1541
      "\xde05",      # CPData Name: surrpair n:1542
      "\xde06",      # CPData Name: surrpair n:1543
      "\xde07",      # CPData Name: surrpair n:1544
      "\xde08",      # CPData Name: surrpair n:1545
      "\xde09",      # CPData Name: surrpair n:1546
      "\xde0a",      # CPData Name: surrpair n:1547
      "\xde0b",      # CPData Name: surrpair n:1548
      "\xde0c",      # CPData Name: surrpair n:1549
      "\xde0d",      # CPData Name: surrpair n:1550
      "\xde0e",      # CPData Name: surrpair n:1551
      "\xde0f",      # CPData Name: surrpair n:1552
      "\xde10",      # CPData Name: surrpair n:1553
      "\xde11",      # CPData Name: surrpair n:1554
      "\xde12",      # CPData Name: surrpair n:1555
      "\xde13",      # CPData Name: surrpair n:1556
      "\xde14",      # CPData Name: surrpair n:1557
      "\xde15",      # CPData Name: surrpair n:1558
      "\xde16",      # CPData Name: surrpair n:1559
      "\xde17",      # CPData Name: surrpair n:1560
      "\xde18",      # CPData Name: surrpair n:1561
      "\xde19",      # CPData Name: surrpair n:1562
      "\xde1a",      # CPData Name: surrpair n:1563
      "\xde1b",      # CPData Name: surrpair n:1564
      "\xde1c",      # CPData Name: surrpair n:1565
      "\xde1d",      # CPData Name: surrpair n:1566
      "\xde1e",      # CPData Name: surrpair n:1567
      "\xde1f",      # CPData Name: surrpair n:1568
      "\xde20",      # CPData Name: surrpair n:1569
      "\xde21",      # CPData Name: surrpair n:1570
      "\xde22",      # CPData Name: surrpair n:1571
      "\xde23",      # CPData Name: surrpair n:1572
      "\xde24",      # CPData Name: surrpair n:1573
      "\xde25",      # CPData Name: surrpair n:1574
      "\xde26",      # CPData Name: surrpair n:1575
      "\xde27",      # CPData Name: surrpair n:1576
      "\xde28",      # CPData Name: surrpair n:1577
      "\xde29",      # CPData Name: surrpair n:1578
      "\xde2a",      # CPData Name: surrpair n:1579
      "\xde2b",      # CPData Name: surrpair n:1580
      "\xde2c",      # CPData Name: surrpair n:1581
      "\xde2d",      # CPData Name: surrpair n:1582
      "\xde2e",      # CPData Name: surrpair n:1583
      "\xde2f",      # CPData Name: surrpair n:1584
      "\xde30",      # CPData Name: surrpair n:1585
      "\xde31",      # CPData Name: surrpair n:1586
      "\xde32",      # CPData Name: surrpair n:1587
      "\xde33",      # CPData Name: surrpair n:1588
      "\xde34",      # CPData Name: surrpair n:1589
      "\xde35",      # CPData Name: surrpair n:1590
      "\xde36",      # CPData Name: surrpair n:1591
      "\xde37",      # CPData Name: surrpair n:1592
      "\xde38",      # CPData Name: surrpair n:1593
      "\xde39",      # CPData Name: surrpair n:1594
      "\xde3a",      # CPData Name: surrpair n:1595
      "\xde3b",      # CPData Name: surrpair n:1596
      "\xde3c",      # CPData Name: surrpair n:1597
      "\xde3d",      # CPData Name: surrpair n:1598
      "\xde3e",      # CPData Name: surrpair n:1599
      "\xde3f",      # CPData Name: surrpair n:1600
      "\xde40",      # CPData Name: surrpair n:1601
      "\xde41",      # CPData Name: surrpair n:1602
      "\xde42",      # CPData Name: surrpair n:1603
      "\xde43",      # CPData Name: surrpair n:1604
      "\xde44",      # CPData Name: surrpair n:1605
      "\xde45",      # CPData Name: surrpair n:1606
      "\xde46",      # CPData Name: surrpair n:1607
      "\xde47",      # CPData Name: surrpair n:1608
      "\xde48",      # CPData Name: surrpair n:1609
      "\xde49",      # CPData Name: surrpair n:1610
      "\xde4a",      # CPData Name: surrpair n:1611
      "\xde4b",      # CPData Name: surrpair n:1612
      "\xde4c",      # CPData Name: surrpair n:1613
      "\xde4d",      # CPData Name: surrpair n:1614
      "\xde4e",      # CPData Name: surrpair n:1615
      "\xde4f",      # CPData Name: surrpair n:1616
      "\xde50",      # CPData Name: surrpair n:1617
      "\xde51",      # CPData Name: surrpair n:1618
      "\xde52",      # CPData Name: surrpair n:1619
      "\xde53",      # CPData Name: surrpair n:1620
      "\xde54",      # CPData Name: surrpair n:1621
      "\xde55",      # CPData Name: surrpair n:1622
      "\xde56",      # CPData Name: surrpair n:1623
      "\xde57",      # CPData Name: surrpair n:1624
      "\xde58",      # CPData Name: surrpair n:1625
      "\xde59",      # CPData Name: surrpair n:1626
      "\xde5a",      # CPData Name: surrpair n:1627
      "\xde5b",      # CPData Name: surrpair n:1628
      "\xde5c",      # CPData Name: surrpair n:1629
      "\xde5d",      # CPData Name: surrpair n:1630
      "\xde5e",      # CPData Name: surrpair n:1631
      "\xde5f",      # CPData Name: surrpair n:1632
      "\xde60",      # CPData Name: surrpair n:1633
      "\xde61",      # CPData Name: surrpair n:1634
      "\xde62",      # CPData Name: surrpair n:1635
      "\xde63",      # CPData Name: surrpair n:1636
      "\xde64",      # CPData Name: surrpair n:1637
      "\xde65",      # CPData Name: surrpair n:1638
      "\xde66",      # CPData Name: surrpair n:1639
      "\xde67",      # CPData Name: surrpair n:1640
      "\xde68",      # CPData Name: surrpair n:1641
      "\xde69",      # CPData Name: surrpair n:1642
      "\xde6a",      # CPData Name: surrpair n:1643
      "\xde6b",      # CPData Name: surrpair n:1644
      "\xde6c",      # CPData Name: surrpair n:1645
      "\xde6d",      # CPData Name: surrpair n:1646
      "\xde6e",      # CPData Name: surrpair n:1647
      "\xde6f",      # CPData Name: surrpair n:1648
      "\xde70",      # CPData Name: surrpair n:1649
      "\xde71",      # CPData Name: surrpair n:1650
      "\xde72",      # CPData Name: surrpair n:1651
      "\xde73",      # CPData Name: surrpair n:1652
      "\xde74",      # CPData Name: surrpair n:1653
      "\xde75",      # CPData Name: surrpair n:1654
      "\xde76",      # CPData Name: surrpair n:1655
      "\xde77",      # CPData Name: surrpair n:1656
      "\xde78",      # CPData Name: surrpair n:1657
      "\xde79",      # CPData Name: surrpair n:1658
      "\xde7a",      # CPData Name: surrpair n:1659
      "\xde7b",      # CPData Name: surrpair n:1660
      "\xde7c",      # CPData Name: surrpair n:1661
      "\xde7d",      # CPData Name: surrpair n:1662
      "\xde7e",      # CPData Name: surrpair n:1663
      "\xde7f",      # CPData Name: surrpair n:1664
      "\xde80",      # CPData Name: surrpair n:1665
      "\xde81",      # CPData Name: surrpair n:1666
      "\xde82",      # CPData Name: surrpair n:1667
      "\xde83",      # CPData Name: surrpair n:1668
      "\xde84",      # CPData Name: surrpair n:1669
      "\xde85",      # CPData Name: surrpair n:1670
      "\xde86",      # CPData Name: surrpair n:1671
      "\xde87",      # CPData Name: surrpair n:1672
      "\xde88",      # CPData Name: surrpair n:1673
      "\xde89",      # CPData Name: surrpair n:1674
      "\xde8a",      # CPData Name: surrpair n:1675
      "\xde8b",      # CPData Name: surrpair n:1676
      "\xde8c",      # CPData Name: surrpair n:1677
      "\xde8d",      # CPData Name: surrpair n:1678
      "\xde8e",      # CPData Name: surrpair n:1679
      "\xde8f",      # CPData Name: surrpair n:1680
      "\xde90",      # CPData Name: surrpair n:1681
      "\xde91",      # CPData Name: surrpair n:1682
      "\xde92",      # CPData Name: surrpair n:1683
      "\xde93",      # CPData Name: surrpair n:1684
      "\xde94",      # CPData Name: surrpair n:1685
      "\xde95",      # CPData Name: surrpair n:1686
      "\xde96",      # CPData Name: surrpair n:1687
      "\xde97",      # CPData Name: surrpair n:1688
      "\xde98",      # CPData Name: surrpair n:1689
      "\xde99",      # CPData Name: surrpair n:1690
      "\xde9a",      # CPData Name: surrpair n:1691
      "\xde9b",      # CPData Name: surrpair n:1692
      "\xde9c",      # CPData Name: surrpair n:1693
      "\xde9d",      # CPData Name: surrpair n:1694
      "\xde9e",      # CPData Name: surrpair n:1695
      "\xde9f",      # CPData Name: surrpair n:1696
      "\xdea0",      # CPData Name: surrpair n:1697
      "\xdea1",      # CPData Name: surrpair n:1698
      "\xdea2",      # CPData Name: surrpair n:1699
      "\xdea3",      # CPData Name: surrpair n:1700
      "\xdea4",      # CPData Name: surrpair n:1701
      "\xdea5",      # CPData Name: surrpair n:1702
      "\xdea6",      # CPData Name: surrpair n:1703
      "\xdea7",      # CPData Name: surrpair n:1704
      "\xdea8",      # CPData Name: surrpair n:1705
      "\xdea9",      # CPData Name: surrpair n:1706
      "\xdeaa",      # CPData Name: surrpair n:1707
      "\xdeab",      # CPData Name: surrpair n:1708
      "\xdeac",      # CPData Name: surrpair n:1709
      "\xdead",      # CPData Name: surrpair n:1710
      "\xdeae",      # CPData Name: surrpair n:1711
      "\xdeaf",      # CPData Name: surrpair n:1712
      "\xdeb0",      # CPData Name: surrpair n:1713
      "\xdeb1",      # CPData Name: surrpair n:1714
      "\xdeb2",      # CPData Name: surrpair n:1715
      "\xdeb3",      # CPData Name: surrpair n:1716
      "\xdeb4",      # CPData Name: surrpair n:1717
      "\xdeb5",      # CPData Name: surrpair n:1718
      "\xdeb6",      # CPData Name: surrpair n:1719
      "\xdeb7",      # CPData Name: surrpair n:1720
      "\xdeb8",      # CPData Name: surrpair n:1721
      "\xdeb9",      # CPData Name: surrpair n:1722
      "\xdeba",      # CPData Name: surrpair n:1723
      "\xdebb",      # CPData Name: surrpair n:1724
      "\xdebc",      # CPData Name: surrpair n:1725
      "\xdebd",      # CPData Name: surrpair n:1726
      "\xdebe",      # CPData Name: surrpair n:1727
      "\xdebf",      # CPData Name: surrpair n:1728
      "\xdec0",      # CPData Name: surrpair n:1729
      "\xdec1",      # CPData Name: surrpair n:1730
      "\xdec2",      # CPData Name: surrpair n:1731
      "\xdec3",      # CPData Name: surrpair n:1732
      "\xdec4",      # CPData Name: surrpair n:1733
      "\xdec5",      # CPData Name: surrpair n:1734
      "\xdec6",      # CPData Name: surrpair n:1735
      "\xdec7",      # CPData Name: surrpair n:1736
      "\xdec8",      # CPData Name: surrpair n:1737
      "\xdec9",      # CPData Name: surrpair n:1738
      "\xdeca",      # CPData Name: surrpair n:1739
      "\xdecb",      # CPData Name: surrpair n:1740
      "\xdecc",      # CPData Name: surrpair n:1741
      "\xdecd",      # CPData Name: surrpair n:1742
      "\xdece",      # CPData Name: surrpair n:1743
      "\xdecf",      # CPData Name: surrpair n:1744
      "\xded0",      # CPData Name: surrpair n:1745
      "\xded1",      # CPData Name: surrpair n:1746
      "\xded2",      # CPData Name: surrpair n:1747
      "\xded3",      # CPData Name: surrpair n:1748
      "\xded4",      # CPData Name: surrpair n:1749
      "\xded5",      # CPData Name: surrpair n:1750
      "\xded6",      # CPData Name: surrpair n:1751
      "\xded7",      # CPData Name: surrpair n:1752
      "\xded8",      # CPData Name: surrpair n:1753
      "\xded9",      # CPData Name: surrpair n:1754
      "\xdeda",      # CPData Name: surrpair n:1755
      "\xdedb",      # CPData Name: surrpair n:1756
      "\xdedc",      # CPData Name: surrpair n:1757
      "\xdedd",      # CPData Name: surrpair n:1758
      "\xdede",      # CPData Name: surrpair n:1759
      "\xdedf",      # CPData Name: surrpair n:1760
      "\xdee0",      # CPData Name: surrpair n:1761
      "\xdee1",      # CPData Name: surrpair n:1762
      "\xdee2",      # CPData Name: surrpair n:1763
      "\xdee3",      # CPData Name: surrpair n:1764
      "\xdee4",      # CPData Name: surrpair n:1765
      "\xdee5",      # CPData Name: surrpair n:1766
      "\xdee6",      # CPData Name: surrpair n:1767
      "\xdee7",      # CPData Name: surrpair n:1768
      "\xdee8",      # CPData Name: surrpair n:1769
      "\xdee9",      # CPData Name: surrpair n:1770
      "\xdeea",      # CPData Name: surrpair n:1771
      "\xdeeb",      # CPData Name: surrpair n:1772
      "\xdeec",      # CPData Name: surrpair n:1773
      "\xdeed",      # CPData Name: surrpair n:1774
      "\xdeee",      # CPData Name: surrpair n:1775
      "\xdeef",      # CPData Name: surrpair n:1776
      "\xdef0",      # CPData Name: surrpair n:1777
      "\xdef1",      # CPData Name: surrpair n:1778
      "\xdef2",      # CPData Name: surrpair n:1779
      "\xdef3",      # CPData Name: surrpair n:1780
      "\xdef4",      # CPData Name: surrpair n:1781
      "\xdef5",      # CPData Name: surrpair n:1782
      "\xdef6",      # CPData Name: surrpair n:1783
      "\xdef7",      # CPData Name: surrpair n:1784
      "\xdef8",      # CPData Name: surrpair n:1785
      "\xdef9",      # CPData Name: surrpair n:1786
      "\xdefa",      # CPData Name: surrpair n:1787
      "\xdefb",      # CPData Name: surrpair n:1788
      "\xdefc",      # CPData Name: surrpair n:1789
      "\xdefd",      # CPData Name: surrpair n:1790
      "\xdefe",      # CPData Name: surrpair n:1791
      "\xdeff",      # CPData Name: surrpair n:1792
      "\xdf00",      # CPData Name: surrpair n:1793
      "\xdf01",      # CPData Name: surrpair n:1794
      "\xdf02",      # CPData Name: surrpair n:1795
      "\xdf03",      # CPData Name: surrpair n:1796
      "\xdf04",      # CPData Name: surrpair n:1797
      "\xdf05",      # CPData Name: surrpair n:1798
      "\xdf06",      # CPData Name: surrpair n:1799
      "\xdf07",      # CPData Name: surrpair n:1800
      "\xdf08",      # CPData Name: surrpair n:1801
      "\xdf09",      # CPData Name: surrpair n:1802
      "\xdf0a",      # CPData Name: surrpair n:1803
      "\xdf0b",      # CPData Name: surrpair n:1804
      "\xdf0c",      # CPData Name: surrpair n:1805
      "\xdf0d",      # CPData Name: surrpair n:1806
      "\xdf0e",      # CPData Name: surrpair n:1807
      "\xdf0f",      # CPData Name: surrpair n:1808
      "\xdf10",      # CPData Name: surrpair n:1809
      "\xdf11",      # CPData Name: surrpair n:1810
      "\xdf12",      # CPData Name: surrpair n:1811
      "\xdf13",      # CPData Name: surrpair n:1812
      "\xdf14",      # CPData Name: surrpair n:1813
      "\xdf15",      # CPData Name: surrpair n:1814
      "\xdf16",      # CPData Name: surrpair n:1815
      "\xdf17",      # CPData Name: surrpair n:1816
      "\xdf18",      # CPData Name: surrpair n:1817
      "\xdf19",      # CPData Name: surrpair n:1818
      "\xdf1a",      # CPData Name: surrpair n:1819
      "\xdf1b",      # CPData Name: surrpair n:1820
      "\xdf1c",      # CPData Name: surrpair n:1821
      "\xdf1d",      # CPData Name: surrpair n:1822
      "\xdf1e",      # CPData Name: surrpair n:1823
      "\xdf1f",      # CPData Name: surrpair n:1824
      "\xdf20",      # CPData Name: surrpair n:1825
      "\xdf21",      # CPData Name: surrpair n:1826
      "\xdf22",      # CPData Name: surrpair n:1827
      "\xdf23",      # CPData Name: surrpair n:1828
      "\xdf24",      # CPData Name: surrpair n:1829
      "\xdf25",      # CPData Name: surrpair n:1830
      "\xdf26",      # CPData Name: surrpair n:1831
      "\xdf27",      # CPData Name: surrpair n:1832
      "\xdf28",      # CPData Name: surrpair n:1833
      "\xdf29",      # CPData Name: surrpair n:1834
      "\xdf2a",      # CPData Name: surrpair n:1835
      "\xdf2b",      # CPData Name: surrpair n:1836
      "\xdf2c",      # CPData Name: surrpair n:1837
      "\xdf2d",      # CPData Name: surrpair n:1838
      "\xdf2e",      # CPData Name: surrpair n:1839
      "\xdf2f",      # CPData Name: surrpair n:1840
      "\xdf30",      # CPData Name: surrpair n:1841
      "\xdf31",      # CPData Name: surrpair n:1842
      "\xdf32",      # CPData Name: surrpair n:1843
      "\xdf33",      # CPData Name: surrpair n:1844
      "\xdf34",      # CPData Name: surrpair n:1845
      "\xdf35",      # CPData Name: surrpair n:1846
      "\xdf36",      # CPData Name: surrpair n:1847
      "\xdf37",      # CPData Name: surrpair n:1848
      "\xdf38",      # CPData Name: surrpair n:1849
      "\xdf39",      # CPData Name: surrpair n:1850
      "\xdf3a",      # CPData Name: surrpair n:1851
      "\xdf3b",      # CPData Name: surrpair n:1852
      "\xdf3c",      # CPData Name: surrpair n:1853
      "\xdf3d",      # CPData Name: surrpair n:1854
      "\xdf3e",      # CPData Name: surrpair n:1855
      "\xdf3f",      # CPData Name: surrpair n:1856
      "\xdf40",      # CPData Name: surrpair n:1857
      "\xdf41",      # CPData Name: surrpair n:1858
      "\xdf42",      # CPData Name: surrpair n:1859
      "\xdf43",      # CPData Name: surrpair n:1860
      "\xdf44",      # CPData Name: surrpair n:1861
      "\xdf45",      # CPData Name: surrpair n:1862
      "\xdf46",      # CPData Name: surrpair n:1863
      "\xdf47",      # CPData Name: surrpair n:1864
      "\xdf48",      # CPData Name: surrpair n:1865
      "\xdf49",      # CPData Name: surrpair n:1866
      "\xdf4a",      # CPData Name: surrpair n:1867
      "\xdf4b",      # CPData Name: surrpair n:1868
      "\xdf4c",      # CPData Name: surrpair n:1869
      "\xdf4d",      # CPData Name: surrpair n:1870
      "\xdf4e",      # CPData Name: surrpair n:1871
      "\xdf4f",      # CPData Name: surrpair n:1872
      "\xdf50",      # CPData Name: surrpair n:1873
      "\xdf51",      # CPData Name: surrpair n:1874
      "\xdf52",      # CPData Name: surrpair n:1875
      "\xdf53",      # CPData Name: surrpair n:1876
      "\xdf54",      # CPData Name: surrpair n:1877
      "\xdf55",      # CPData Name: surrpair n:1878
      "\xdf56",      # CPData Name: surrpair n:1879
      "\xdf57",      # CPData Name: surrpair n:1880
      "\xdf58",      # CPData Name: surrpair n:1881
      "\xdf59",      # CPData Name: surrpair n:1882
      "\xdf5a",      # CPData Name: surrpair n:1883
      "\xdf5b",      # CPData Name: surrpair n:1884
      "\xdf5c",      # CPData Name: surrpair n:1885
      "\xdf5d",      # CPData Name: surrpair n:1886
      "\xdf5e",      # CPData Name: surrpair n:1887
      "\xdf5f",      # CPData Name: surrpair n:1888
      "\xdf60",      # CPData Name: surrpair n:1889
      "\xdf61",      # CPData Name: surrpair n:1890
      "\xdf62",      # CPData Name: surrpair n:1891
      "\xdf63",      # CPData Name: surrpair n:1892
      "\xdf64",      # CPData Name: surrpair n:1893
      "\xdf65",      # CPData Name: surrpair n:1894
      "\xdf66",      # CPData Name: surrpair n:1895
      "\xdf67",      # CPData Name: surrpair n:1896
      "\xdf68",      # CPData Name: surrpair n:1897
      "\xdf69",      # CPData Name: surrpair n:1898
      "\xdf6a",      # CPData Name: surrpair n:1899
      "\xdf6b",      # CPData Name: surrpair n:1900
      "\xdf6c",      # CPData Name: surrpair n:1901
      "\xdf6d",      # CPData Name: surrpair n:1902
      "\xdf6e",      # CPData Name: surrpair n:1903
      "\xdf6f",      # CPData Name: surrpair n:1904
      "\xdf70",      # CPData Name: surrpair n:1905
      "\xdf71",      # CPData Name: surrpair n:1906
      "\xdf72",      # CPData Name: surrpair n:1907
      "\xdf73",      # CPData Name: surrpair n:1908
      "\xdf74",      # CPData Name: surrpair n:1909
      "\xdf75",      # CPData Name: surrpair n:1910
      "\xdf76",      # CPData Name: surrpair n:1911
      "\xdf77",      # CPData Name: surrpair n:1912
      "\xdf78",      # CPData Name: surrpair n:1913
      "\xdf79",      # CPData Name: surrpair n:1914
      "\xdf7a",      # CPData Name: surrpair n:1915
      "\xdf7b",      # CPData Name: surrpair n:1916
      "\xdf7c",      # CPData Name: surrpair n:1917
      "\xdf7d",      # CPData Name: surrpair n:1918
      "\xdf7e",      # CPData Name: surrpair n:1919
      "\xdf7f",      # CPData Name: surrpair n:1920
      "\xdf80",      # CPData Name: surrpair n:1921
      "\xdf81",      # CPData Name: surrpair n:1922
      "\xdf82",      # CPData Name: surrpair n:1923
      "\xdf83",      # CPData Name: surrpair n:1924
      "\xdf84",      # CPData Name: surrpair n:1925
      "\xdf85",      # CPData Name: surrpair n:1926
      "\xdf86",      # CPData Name: surrpair n:1927
      "\xdf87",      # CPData Name: surrpair n:1928
      "\xdf88",      # CPData Name: surrpair n:1929
      "\xdf89",      # CPData Name: surrpair n:1930
      "\xdf8a",      # CPData Name: surrpair n:1931
      "\xdf8b",      # CPData Name: surrpair n:1932
      "\xdf8c",      # CPData Name: surrpair n:1933
      "\xdf8d",      # CPData Name: surrpair n:1934
      "\xdf8e",      # CPData Name: surrpair n:1935
      "\xdf8f",      # CPData Name: surrpair n:1936
      "\xdf90",      # CPData Name: surrpair n:1937
      "\xdf91",      # CPData Name: surrpair n:1938
      "\xdf92",      # CPData Name: surrpair n:1939
      "\xdf93",      # CPData Name: surrpair n:1940
      "\xdf94",      # CPData Name: surrpair n:1941
      "\xdf95",      # CPData Name: surrpair n:1942
      "\xdf96",      # CPData Name: surrpair n:1943
      "\xdf97",      # CPData Name: surrpair n:1944
      "\xdf98",      # CPData Name: surrpair n:1945
      "\xdf99",      # CPData Name: surrpair n:1946
      "\xdf9a",      # CPData Name: surrpair n:1947
      "\xdf9b",      # CPData Name: surrpair n:1948
      "\xdf9c",      # CPData Name: surrpair n:1949
      "\xdf9d",      # CPData Name: surrpair n:1950
      "\xdf9e",      # CPData Name: surrpair n:1951
      "\xdf9f",      # CPData Name: surrpair n:1952
      "\xdfa0",      # CPData Name: surrpair n:1953
      "\xdfa1",      # CPData Name: surrpair n:1954
      "\xdfa2",      # CPData Name: surrpair n:1955
      "\xdfa3",      # CPData Name: surrpair n:1956
      "\xdfa4",      # CPData Name: surrpair n:1957
      "\xdfa5",      # CPData Name: surrpair n:1958
      "\xdfa6",      # CPData Name: surrpair n:1959
      "\xdfa7",      # CPData Name: surrpair n:1960
      "\xdfa8",      # CPData Name: surrpair n:1961
      "\xdfa9",      # CPData Name: surrpair n:1962
      "\xdfaa",      # CPData Name: surrpair n:1963
      "\xdfab",      # CPData Name: surrpair n:1964
      "\xdfac",      # CPData Name: surrpair n:1965
      "\xdfad",      # CPData Name: surrpair n:1966
      "\xdfae",      # CPData Name: surrpair n:1967
      "\xdfaf",      # CPData Name: surrpair n:1968
      "\xdfb0",      # CPData Name: surrpair n:1969
      "\xdfb1",      # CPData Name: surrpair n:1970
      "\xdfb2",      # CPData Name: surrpair n:1971
      "\xdfb3",      # CPData Name: surrpair n:1972
      "\xdfb4",      # CPData Name: surrpair n:1973
      "\xdfb5",      # CPData Name: surrpair n:1974
      "\xdfb6",      # CPData Name: surrpair n:1975
      "\xdfb7",      # CPData Name: surrpair n:1976
      "\xdfb8",      # CPData Name: surrpair n:1977
      "\xdfb9",      # CPData Name: surrpair n:1978
      "\xdfba",      # CPData Name: surrpair n:1979
      "\xdfbb",      # CPData Name: surrpair n:1980
      "\xdfbc",      # CPData Name: surrpair n:1981
      "\xdfbd",      # CPData Name: surrpair n:1982
      "\xdfbe",      # CPData Name: surrpair n:1983
      "\xdfbf",      # CPData Name: surrpair n:1984
      "\xdfc0",      # CPData Name: surrpair n:1985
      "\xdfc1",      # CPData Name: surrpair n:1986
      "\xdfc2",      # CPData Name: surrpair n:1987
      "\xdfc3",      # CPData Name: surrpair n:1988
      "\xdfc4",      # CPData Name: surrpair n:1989
      "\xdfc5",      # CPData Name: surrpair n:1990
      "\xdfc6",      # CPData Name: surrpair n:1991
      "\xdfc7",      # CPData Name: surrpair n:1992
      "\xdfc8",      # CPData Name: surrpair n:1993
      "\xdfc9",      # CPData Name: surrpair n:1994
      "\xdfca",      # CPData Name: surrpair n:1995
      "\xdfcb",      # CPData Name: surrpair n:1996
      "\xdfcc",      # CPData Name: surrpair n:1997
      "\xdfcd",      # CPData Name: surrpair n:1998
      "\xdfce",      # CPData Name: surrpair n:1999
      "\xdfcf",      # CPData Name: surrpair n:2000
      "\xdfd0",      # CPData Name: surrpair n:2001
      "\xdfd1",      # CPData Name: surrpair n:2002
      "\xdfd2",      # CPData Name: surrpair n:2003
      "\xdfd3",      # CPData Name: surrpair n:2004
      "\xdfd4",      # CPData Name: surrpair n:2005
      "\xdfd5",      # CPData Name: surrpair n:2006
      "\xdfd6",      # CPData Name: surrpair n:2007
      "\xdfd7",      # CPData Name: surrpair n:2008
      "\xdfd8",      # CPData Name: surrpair n:2009
      "\xdfd9",      # CPData Name: surrpair n:2010
      "\xdfda",      # CPData Name: surrpair n:2011
      "\xdfdb",      # CPData Name: surrpair n:2012
      "\xdfdc",      # CPData Name: surrpair n:2013
      "\xdfdd",      # CPData Name: surrpair n:2014
      "\xdfde",      # CPData Name: surrpair n:2015
      "\xdfdf",      # CPData Name: surrpair n:2016
      "\xdfe0",      # CPData Name: surrpair n:2017
      "\xdfe1",      # CPData Name: surrpair n:2018
      "\xdfe2",      # CPData Name: surrpair n:2019
      "\xdfe3",      # CPData Name: surrpair n:2020
      "\xdfe4",      # CPData Name: surrpair n:2021
      "\xdfe5",      # CPData Name: surrpair n:2022
      "\xdfe6",      # CPData Name: surrpair n:2023
      "\xdfe7",      # CPData Name: surrpair n:2024
      "\xdfe8",      # CPData Name: surrpair n:2025
      "\xdfe9",      # CPData Name: surrpair n:2026
      "\xdfea",      # CPData Name: surrpair n:2027
      "\xdfeb",      # CPData Name: surrpair n:2028
      "\xdfec",      # CPData Name: surrpair n:2029
      "\xdfed",      # CPData Name: surrpair n:2030
      "\xdfee",      # CPData Name: surrpair n:2031
      "\xdfef",      # CPData Name: surrpair n:2032
      "\xdff0",      # CPData Name: surrpair n:2033
      "\xdff1",      # CPData Name: surrpair n:2034
      "\xdff2",      # CPData Name: surrpair n:2035
      "\xdff3",      # CPData Name: surrpair n:2036
      "\xdff4",      # CPData Name: surrpair n:2037
      "\xdff5",      # CPData Name: surrpair n:2038
      "\xdff6",      # CPData Name: surrpair n:2039
      "\xdff7",      # CPData Name: surrpair n:2040
      "\xdff8",      # CPData Name: surrpair n:2041
      "\xdff9",      # CPData Name: surrpair n:2042
      "\xdffa",      # CPData Name: surrpair n:2043
      "\xdffb",      # CPData Name: surrpair n:2044
      "\xdffc",      # CPData Name: surrpair n:2045
      "\xdffd",      # CPData Name: surrpair n:2046
      "\xdffe",      # CPData Name: surrpair n:2047
      "\xdfff",      # CPData Name: surrpair n:2048
    ]
    test_data.each do |string|
      assert !@validator.valid_encoding?(string), "utf16_surrogate_pairs_first_half A: #{string}"
      assert !string.force_encoding("UTF-8").valid_encoding?,
        "utf16_surrogate_pairs_first_half B: #{string}"  if @vercheck
    end
  end

end # of class
